@@ -60,12 +60,10 @@ namespace executor_example {
 
     public:
         using execution_category = typename BaseExecutor::execution_category;
-        using executor_parameters_type =
-            typename BaseExecutor::executor_parameters_type;
+        using executor_parameters_type = typename BaseExecutor::executor_parameters_type;
 
         template <typename OnStart, typename OnStop>
-        executor_with_thread_hooks(
-            BaseExecutor& exec, OnStart&& start, OnStop&& stop)
+        executor_with_thread_hooks(BaseExecutor& exec, OnStart&& start, OnStop&& stop)
           : exec_(exec)
           , on_start_(std::forward<OnStart>(start))
           , on_stop_(std::forward<OnStop>(stop))
@@ -91,61 +89,53 @@ namespace executor_example {
         template <typename F, typename... Ts>
         decltype(auto) sync_execute(F&& f, Ts&&... ts) const
         {
-            return pika::parallel::execution::sync_execute(exec_,
-                hook_wrapper<F>{*this, std::forward<F>(f)},
-                std::forward<Ts>(ts)...);
+            return pika::parallel::execution::sync_execute(
+                exec_, hook_wrapper<F>{*this, std::forward<F>(f)}, std::forward<Ts>(ts)...);
         }
 
         // TwoWayExecutor interface
         template <typename F, typename... Ts>
         decltype(auto) async_execute(F&& f, Ts&&... ts) const
         {
-            return pika::parallel::execution::async_execute(exec_,
-                hook_wrapper<F>{*this, std::forward<F>(f)},
-                std::forward<Ts>(ts)...);
+            return pika::parallel::execution::async_execute(
+                exec_, hook_wrapper<F>{*this, std::forward<F>(f)}, std::forward<Ts>(ts)...);
         }
 
         template <typename F, typename Future, typename... Ts>
-        decltype(auto)
-        then_execute(F&& f, Future&& predecessor, Ts&&... ts) const
+        decltype(auto) then_execute(F&& f, Future&& predecessor, Ts&&... ts) const
         {
             return pika::parallel::execution::then_execute(exec_,
-                hook_wrapper<F>{*this, std::forward<F>(f)},
-                std::forward<Future>(predecessor), std::forward<Ts>(ts)...);
+                hook_wrapper<F>{*this, std::forward<F>(f)}, std::forward<Future>(predecessor),
+                std::forward<Ts>(ts)...);
         }
 
         // NonBlockingOneWayExecutor (adapted) interface
         template <typename F, typename... Ts>
         void post(F&& f, Ts&&... ts) const
         {
-            pika::parallel::execution::post(exec_,
-                hook_wrapper<F>{*this, std::forward<F>(f)},
-                std::forward<Ts>(ts)...);
+            pika::parallel::execution::post(
+                exec_, hook_wrapper<F>{*this, std::forward<F>(f)}, std::forward<Ts>(ts)...);
         }
 
         // BulkOneWayExecutor interface
         template <typename F, typename S, typename... Ts>
-        decltype(auto)
-        bulk_sync_execute(F&& f, S const& shape, Ts&&... ts) const
+        decltype(auto) bulk_sync_execute(F&& f, S const& shape, Ts&&... ts) const
         {
-            return pika::parallel::execution::bulk_sync_execute(exec_,
-                hook_wrapper<F>{*this, std::forward<F>(f)}, shape,
-                std::forward<Ts>(ts)...);
+            return pika::parallel::execution::bulk_sync_execute(
+                exec_, hook_wrapper<F>{*this, std::forward<F>(f)}, shape, std::forward<Ts>(ts)...);
         }
 
         // BulkTwoWayExecutor interface
         template <typename F, typename S, typename... Ts>
-        decltype(auto)
-        bulk_async_execute(F&& f, S const& shape, Ts&&... ts) const
+        decltype(auto) bulk_async_execute(F&& f, S const& shape, Ts&&... ts) const
         {
-            return pika::parallel::execution::bulk_async_execute(exec_,
-                hook_wrapper<F>{*this, std::forward<F>(f)}, shape,
-                std::forward<Ts>(ts)...);
+            return pika::parallel::execution::bulk_async_execute(
+                exec_, hook_wrapper<F>{*this, std::forward<F>(f)}, shape, std::forward<Ts>(ts)...);
         }
 
         template <typename F, typename S, typename Future, typename... Ts>
-        decltype(auto) bulk_then_execute(
-            F&& f, S const& shape, Future&& predecessor, Ts&&... ts) const
+        decltype(auto)
+        bulk_then_execute(F&& f, S const& shape, Future&& predecessor, Ts&&... ts) const
         {
             return pika::parallel::execution::bulk_then_execute(exec_,
                 hook_wrapper<F>{*this, std::forward<F>(f)}, shape,
@@ -161,11 +151,11 @@ namespace executor_example {
     };
 
     template <typename BaseExecutor, typename OnStart, typename OnStop>
-    executor_with_thread_hooks<BaseExecutor> make_executor_with_thread_hooks(
-        BaseExecutor& exec, OnStart&& on_start, OnStop&& on_stop)
+    executor_with_thread_hooks<BaseExecutor>
+    make_executor_with_thread_hooks(BaseExecutor& exec, OnStart&& on_start, OnStop&& on_stop)
     {
-        return executor_with_thread_hooks<BaseExecutor>(exec,
-            std::forward<OnStart>(on_start), std::forward<OnStop>(on_stop));
+        return executor_with_thread_hooks<BaseExecutor>(
+            exec, std::forward<OnStart>(on_start), std::forward<OnStop>(on_stop));
     }
 }    // namespace executor_example
 
@@ -174,8 +164,7 @@ namespace executor_example {
 namespace pika::parallel::execution {
 
     template <typename BaseExecutor>
-    struct is_one_way_executor<
-        executor_example::executor_with_thread_hooks<BaseExecutor>>
+    struct is_one_way_executor<executor_example::executor_with_thread_hooks<BaseExecutor>>
       : is_one_way_executor<std::decay_t<BaseExecutor>>
     {
     };
@@ -188,22 +177,19 @@ namespace pika::parallel::execution {
     };
 
     template <typename BaseExecutor>
-    struct is_two_way_executor<
-        executor_example::executor_with_thread_hooks<BaseExecutor>>
+    struct is_two_way_executor<executor_example::executor_with_thread_hooks<BaseExecutor>>
       : is_two_way_executor<std::decay_t<BaseExecutor>>
     {
     };
 
     template <typename BaseExecutor>
-    struct is_bulk_one_way_executor<
-        executor_example::executor_with_thread_hooks<BaseExecutor>>
+    struct is_bulk_one_way_executor<executor_example::executor_with_thread_hooks<BaseExecutor>>
       : is_bulk_one_way_executor<std::decay_t<BaseExecutor>>
     {
     };
 
     template <typename BaseExecutor>
-    struct is_bulk_two_way_executor<
-        executor_example::executor_with_thread_hooks<BaseExecutor>>
+    struct is_bulk_two_way_executor<executor_example::executor_with_thread_hooks<BaseExecutor>>
       : is_bulk_two_way_executor<std::decay_t<BaseExecutor>>
     {
     };
@@ -226,8 +212,7 @@ int pika_main()
     pika::parallel::execution::bulk_sync_execute(
         exec, [](std::size_t) {}, v.size());
 
-    std::cout << "Executed " << starts.load() << " starts and " << stops.load()
-              << " stops\n";
+    std::cout << "Executed " << starts.load() << " starts and " << stops.load() << " stops\n";
 
     PIKA_ASSERT(starts.load() != 0);
     PIKA_ASSERT(stops.load() != 0);
