@@ -14,6 +14,7 @@
 #include <fmt/ostream.h>
 #include <fmt/printf.h>
 
+#include <chrono>
 #include <cstddef>
 #include <cstdint>
 #include <iostream>
@@ -33,8 +34,7 @@ PIKA_NOINLINE std::uint64_t fibonacci_serial(std::uint64_t n)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-std::uint64_t add(
-    pika::future<std::uint64_t> f1, pika::future<std::uint64_t> f2)
+std::uint64_t add(pika::future<std::uint64_t> f1, pika::future<std::uint64_t> f2)
 {
     return f1.get() + f2.get();
 }
@@ -42,8 +42,7 @@ std::uint64_t add(
 ///////////////////////////////////////////////////////////////////////////////
 struct when_all_wrapper
 {
-    using data_type =
-        std::tuple<pika::future<std::uint64_t>, pika::future<std::uint64_t>>;
+    using data_type = std::tuple<pika::future<std::uint64_t>, pika::future<std::uint64_t>>;
 
     std::uint64_t operator()(pika::future<data_type> data) const
     {
@@ -117,8 +116,7 @@ std::uint64_t fibonacci_fork(std::uint64_t n)
 
     // asynchronously launch the creation of one of the sub-terms of the
     // execution graph
-    pika::future<std::uint64_t> f =
-        pika::async(pika::launch::fork, &fibonacci_fork, n - 1);
+    pika::future<std::uint64_t> f = pika::async(pika::launch::fork, &fibonacci_fork, n - 1);
     std::uint64_t r = fibonacci_fork(n - 2);
 
     return f.get() + r;
@@ -152,8 +150,7 @@ pika::future<std::uint64_t> fibonacci_future_fork(std::uint64_t n)
 
     // asynchronously launch the creation of one of the sub-terms of the
     // execution graph
-    pika::future<std::uint64_t> f =
-        pika::async(pika::launch::fork, &fibonacci_future_fork, n - 1);
+    pika::future<std::uint64_t> f = pika::async(pika::launch::fork, &fibonacci_future_fork, n - 1);
     pika::future<std::uint64_t> r = fibonacci_future_fork(n - 2);
 
     return pika::async(&add, std::move(f), std::move(r));
@@ -170,8 +167,7 @@ pika::future<std::uint64_t> fibonacci_future_when_all(std::uint64_t n)
 
     // asynchronously launch the creation of one of the sub-terms of the
     // execution graph
-    pika::future<pika::future<std::uint64_t>> f =
-        pika::async(&fibonacci_future, n - 1);
+    pika::future<pika::future<std::uint64_t>> f = pika::async(&fibonacci_future, n - 1);
     pika::future<std::uint64_t> r = fibonacci_future(n - 2);
 
     return pika::when_all(f.get(), r).then(when_all_wrapper());
@@ -241,8 +237,8 @@ int pika_main(pika::program_options::variables_map& vm)
 
     if (max_runs == 0)
     {
-        std::cerr << "fibonacci_futures: wrong command line argument value for "
-                     "option 'n-runs', should not be zero"
+        std::cerr << "fibonacci_futures: wrong command line argument value for option 'n-runs', "
+                     "should not be zero"
                   << std::endl;
         return -1;
     }
@@ -250,9 +246,8 @@ int pika_main(pika::program_options::variables_map& vm)
     threshold = vm["threshold"].as<unsigned int>();
     if (threshold < 2 || threshold > n)
     {
-        std::cerr << "fibonacci_futures: wrong command line argument value for "
-                     "option 'threshold', should be in between 2 and n-value"
-                     ", value specified: "
+        std::cerr << "fibonacci_futures: wrong command line argument value for option 'threshold', "
+                     "should be in between 2 and n-value, value specified: "
                   << threshold << std::endl;
         return -1;
     }
@@ -273,11 +268,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_serial(n);
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt = "fibonacci_serial({}) == {},"
-                                    "elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_serial({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -295,11 +287,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future_one(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt = "fibonacci_future_one({}) == {},"
-                                    "elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_future_one({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -317,11 +306,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci(n);
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt =
-            "fibonacci({}) == {},elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -339,11 +325,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_fork(n);
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt =
-            "fibonacci_fork({}) == {},elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_fork({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -361,11 +344,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt =
-            "fibonacci_future({}) == {},elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_future({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -383,11 +363,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future_fork(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt =
-            "fibonacci_future_fork({}) == {},elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_future_fork({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -405,11 +382,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future_when_all(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt =
-            "fibonacci_future_when_all({}) == {},elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_future_when_all({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -427,12 +401,9 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future_unwrapped_when_all(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
         constexpr char const* fmt =
-            "fibonacci_future_unwrapped_when_all({}) == "
-            "{},elapsed time:,{},[s]\n";
+            "fibonacci_future_unwrapped_when_all({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -450,11 +421,8 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future_all(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
-        constexpr char const* fmt =
-            "fibonacci_future_all({}) == {},elapsed time:,{},[s]\n";
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
+        constexpr char const* fmt = "fibonacci_future_all({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
 
         executed_one = true;
@@ -472,9 +440,7 @@ int pika_main(pika::program_options::variables_map& vm)
             r = fibonacci_future_all_when_all(n).get();
         }
 
-        std::uint64_t d =
-            duration_cast<nanoseconds>(high_resolution_clock::now() - start)
-                .count();
+        std::uint64_t d = duration_cast<nanoseconds>(high_resolution_clock::now() - start).count();
         constexpr char const* fmt =
             "fibonacci_future_all_when_all({}) == {},elapsed time:,{},[s]\n";
         fmt::print(std::cout, fmt, n, r, d / max_runs);
@@ -484,10 +450,8 @@ int pika_main(pika::program_options::variables_map& vm)
 
     if (!executed_one)
     {
-        std::cerr << "fibonacci_futures: wrong command line argument value for "
-                     "option 'tests', should be either 'all' or a number "
-                     "between zero "
-                     "and 7, value specified: "
+        std::cerr << "fibonacci_futures: wrong command line argument value for option 'tests', "
+                     "should be either 'all' or a number between zero and 7, value specified: "
                   << test << std::endl;
     }
 
