@@ -15,7 +15,7 @@
 
 namespace pika::detail {
     /// \cond NOINTERNAL
-    PIKA_EXPORT void handle_assert(source_location const& loc, const char* expr,
-        std::string const& msg) noexcept;
+    PIKA_EXPORT void handle_assert(
+        source_location const& loc, const char* expr, std::string const& msg) noexcept;
     /// \endcond
 }    // namespace pika::detail
