@@ -47,8 +47,8 @@ void test_when_each_from_list()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -98,8 +98,8 @@ void test_when_each_from_list_iterators()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -117,11 +117,9 @@ void test_when_each_from_list_iterators()
         futures2.push_back(pika::async(make_unsigned_slowly{j}));
     }
 
-    pika::future<void> r =
-        pika::when_each(callback, futures1.begin(), futures1.end());
+    pika::future<void> r = pika::when_each(callback, futures1.begin(), futures1.end());
 
-    pika::future<void> rwi =
-        pika::when_each(callback_with_index, futures2.begin(), futures2.end());
+    pika::future<void> rwi = pika::when_each(callback_with_index, futures2.begin(), futures2.end());
 
     r.get();
     rwi.get();
@@ -153,8 +151,8 @@ void test_when_each_n_from_list_iterators()
         PIKA_TEST_LT(id, n);
     };
 
-    auto callback_with_index_n = [n, &call_with_index_count](std::size_t idx,
-                                     pika::future<unsigned> fut) {
+    auto callback_with_index_n = [n, &call_with_index_count](
+                                     std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -174,8 +172,7 @@ void test_when_each_n_from_list_iterators()
 
     pika::future<void> r = pika::when_each_n(callback_n, futures1.begin(), n);
 
-    pika::future<void> rwi =
-        pika::when_each_n(callback_with_index_n, futures2.begin(), n);
+    pika::future<void> rwi = pika::when_each_n(callback_with_index_n, futures2.begin(), n);
 
     r.get();
     rwi.get();
@@ -210,8 +207,8 @@ void test_when_each_one_future()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -220,10 +217,8 @@ void test_when_each_one_future()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g =
-        pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g = pika::make_ready_future(static_cast<unsigned>(0));
 
     pika::future<void> r = pika::when_each(callback, std::move(f));
     pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g));
@@ -252,8 +247,8 @@ void test_when_each_two_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -262,20 +257,14 @@ void test_when_each_two_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
 
-    pika::future<void> r =
-        pika::when_each(callback, std::move(f1), std::move(f2));
+    pika::future<void> r = pika::when_each(callback, std::move(f1), std::move(f2));
 
-    pika::future<void> rwi =
-        pika::when_each(callback_with_index, std::move(g1), std::move(g2));
+    pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g1), std::move(g2));
 
     r.get();
     rwi.get();
@@ -303,8 +292,8 @@ void test_when_each_three_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -313,24 +302,17 @@ void test_when_each_three_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> f3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g3 = pika::make_ready_future(static_cast<unsigned>(2));
 
-    pika::future<void> r =
-        pika::when_each(callback, std::move(f1), std::move(f2), std::move(f3));
+    pika::future<void> r = pika::when_each(callback, std::move(f1), std::move(f2), std::move(f3));
 
-    pika::future<void> rwi = pika::when_each(
-        callback_with_index, std::move(g1), std::move(g2), std::move(g3));
+    pika::future<void> rwi =
+        pika::when_each(callback_with_index, std::move(g1), std::move(g2), std::move(g3));
 
     r.get();
     rwi.get();
@@ -360,8 +342,8 @@ void test_when_each_four_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -370,28 +352,20 @@ void test_when_each_four_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> f3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> f4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> g4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> f4 = pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> g4 = pika::make_ready_future(static_cast<unsigned>(3));
 
-    pika::future<void> r = pika::when_each(
-        callback, std::move(f1), std::move(f2), std::move(f3), std::move(f4));
+    pika::future<void> r =
+        pika::when_each(callback, std::move(f1), std::move(f2), std::move(f3), std::move(f4));
 
-    pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g1),
-        std::move(g2), std::move(g3), std::move(g4));
+    pika::future<void> rwi = pika::when_each(
+        callback_with_index, std::move(g1), std::move(g2), std::move(g3), std::move(g4));
 
     r.get();
     rwi.get();
@@ -423,8 +397,8 @@ void test_when_each_five_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -433,32 +407,22 @@ void test_when_each_five_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> f2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> f3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> f4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
-    pika::future<unsigned> f5 =
-        pika::make_ready_future(static_cast<unsigned>(4));
-    pika::future<unsigned> g1 =
-        pika::make_ready_future(static_cast<unsigned>(0));
-    pika::future<unsigned> g2 =
-        pika::make_ready_future(static_cast<unsigned>(1));
-    pika::future<unsigned> g3 =
-        pika::make_ready_future(static_cast<unsigned>(2));
-    pika::future<unsigned> g4 =
-        pika::make_ready_future(static_cast<unsigned>(3));
-    pika::future<unsigned> g5 =
-        pika::make_ready_future(static_cast<unsigned>(4));
+    pika::future<unsigned> f1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> f2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> f3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> f4 = pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> f5 = pika::make_ready_future(static_cast<unsigned>(4));
+    pika::future<unsigned> g1 = pika::make_ready_future(static_cast<unsigned>(0));
+    pika::future<unsigned> g2 = pika::make_ready_future(static_cast<unsigned>(1));
+    pika::future<unsigned> g3 = pika::make_ready_future(static_cast<unsigned>(2));
+    pika::future<unsigned> g4 = pika::make_ready_future(static_cast<unsigned>(3));
+    pika::future<unsigned> g5 = pika::make_ready_future(static_cast<unsigned>(4));
 
-    pika::future<void> r = pika::when_each(callback, std::move(f1),
-        std::move(f2), std::move(f3), std::move(f4), std::move(f5));
+    pika::future<void> r = pika::when_each(
+        callback, std::move(f1), std::move(f2), std::move(f3), std::move(f4), std::move(f5));
 
-    pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g1),
-        std::move(g2), std::move(g3), std::move(g4), std::move(g5));
+    pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g1), std::move(g2),
+        std::move(g3), std::move(g4), std::move(g5));
 
     r.get();
     rwi.get();
@@ -492,8 +456,8 @@ void test_when_each_late_future()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -511,8 +475,7 @@ void test_when_each_late_future()
     pt0.apply();
     pika::future<unsigned> f2 = pt1.get_future();
 
-    pika::future<void> r =
-        pika::when_each(callback, std::move(f1), std::move(f2));
+    pika::future<void> r = pika::when_each(callback, std::move(f1), std::move(f2));
 
     pt1.apply();
 
@@ -525,8 +488,7 @@ void test_when_each_late_future()
     pt2.apply();
     pika::future<unsigned> g2 = pt3.get_future();
 
-    pika::future<void> rwi =
-        pika::when_each(callback_with_index, std::move(g1), std::move(g2));
+    pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g1), std::move(g2));
 
     pt3.apply();
 
@@ -553,8 +515,8 @@ void test_when_each_deferred_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    auto callback_with_index = [count, &call_with_index_count](std::size_t idx,
-                                   pika::future<unsigned> fut) {
+    auto callback_with_index = [count, &call_with_index_count](
+                                   std::size_t idx, pika::future<unsigned> fut) {
         ++call_with_index_count;
 
         unsigned id = fut.get();
@@ -563,21 +525,15 @@ void test_when_each_deferred_futures()
         PIKA_TEST_LT(id, count);
     };
 
-    pika::future<unsigned> f1 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{0});
-    pika::future<unsigned> f2 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{1});
+    pika::future<unsigned> f1 = pika::async(pika::launch::deferred, make_unsigned_slowly{0});
+    pika::future<unsigned> f2 = pika::async(pika::launch::deferred, make_unsigned_slowly{1});
 
-    pika::future<unsigned> g1 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{0});
-    pika::future<unsigned> g2 =
-        pika::async(pika::launch::deferred, make_unsigned_slowly{1});
+    pika::future<unsigned> g1 = pika::async(pika::launch::deferred, make_unsigned_slowly{0});
+    pika::future<unsigned> g2 = pika::async(pika::launch::deferred, make_unsigned_slowly{1});
 
-    pika::future<void> r =
-        pika::when_each(callback, std::move(f1), std::move(f2));
+    pika::future<void> r = pika::when_each(callback, std::move(f1), std::move(f2));
 
-    pika::future<void> rwi =
-        pika::when_each(callback_with_index, std::move(g1), std::move(g2));
+    pika::future<void> rwi = pika::when_each(callback_with_index, std::move(g1), std::move(g2));
 
     r.get();
     rwi.get();
