@@ -17,13 +17,11 @@
 #include <vector>
 
 namespace pika::cuda::experimental {
-    cuda_pool::streams_holder::streams_holder(int device,
-        std::size_t num_streams_per_thread,
+    cuda_pool::streams_holder::streams_holder(int device, std::size_t num_streams_per_thread,
         pika::execution::thread_priority priority, unsigned int flags)
       : num_streams_per_thread(num_streams_per_thread)
       , concurrency(pika::threads::detail::hardware_concurrency())
-      , streams(num_streams_per_thread * concurrency,
-            cuda_stream{device, priority, flags})
+      , streams(num_streams_per_thread * concurrency, cuda_stream{device, priority, flags})
       , active_stream_indices(concurrency, {0})
     {
         PIKA_ASSERT(num_streams_per_thread > 0);
@@ -33,18 +31,14 @@ namespace pika::cuda::experimental {
     {
         // We do not care if there is oversubscription and t is bigger than
         // hardware_concurrency; we simply wrap it around
-        auto const t =
-            pika::threads::detail::get_global_thread_num_tss() % concurrency;
-        auto const local_stream_index =
-            ++(active_stream_indices[t].data_) % num_streams_per_thread;
-        auto const global_stream_index =
-            t * num_streams_per_thread + local_stream_index;
+        auto const t = pika::threads::detail::get_global_thread_num_tss() % concurrency;
+        auto const local_stream_index = ++(active_stream_indices[t].data_) % num_streams_per_thread;
+        auto const global_stream_index = t * num_streams_per_thread + local_stream_index;
 
         return streams[global_stream_index];
     }
 
-    cuda_pool::pool_data::pool_data(int device,
-        std::size_t num_normal_priority_streams_per_thread,
+    cuda_pool::pool_data::pool_data(int device, std::size_t num_normal_priority_streams_per_thread,
         std::size_t num_high_priority_streams_per_thread, unsigned int flags)
       : device(device)
       , normal_priority_streams(device, num_normal_priority_streams_per_thread,
@@ -54,11 +48,9 @@ namespace pika::cuda::experimental {
     {
     }
 
-    cuda_pool::cuda_pool(int device,
-        std::size_t num_normal_priority_streams_per_thread,
+    cuda_pool::cuda_pool(int device, std::size_t num_normal_priority_streams_per_thread,
         std::size_t num_high_priority_streams_per_thread, unsigned int flags)
-      : data(std::make_shared<pool_data>(device,
-            num_normal_priority_streams_per_thread,
+      : data(std::make_shared<pool_data>(device, num_normal_priority_streams_per_thread,
             num_high_priority_streams_per_thread, flags))
     {
     }
@@ -73,8 +65,7 @@ namespace pika::cuda::experimental {
         return bool(data);
     }
 
-    cuda_stream const& cuda_pool::get_next_stream(
-        pika::execution::thread_priority priority)
+    cuda_stream const& cuda_pool::get_next_stream(pika::execution::thread_priority priority)
     {
         PIKA_ASSERT(data);
 
