@@ -31,8 +31,7 @@
 namespace pika::mpi::experimental {
     namespace transform_mpi_detail {
         template <typename Receiver, typename... Ts>
-        void set_value_request_callback_helper(
-            int mpi_status, Receiver&& receiver, Ts&&... ts)
+        void set_value_request_callback_helper(int mpi_status, Receiver&& receiver, Ts&&... ts)
         {
             static_assert(sizeof...(Ts) <= 1, "Expecting at most one value");
             if (mpi_status == MPI_SUCCESS)
@@ -42,36 +41,30 @@ namespace pika::mpi::experimental {
             }
             else
             {
-                pika::execution::experimental::set_error(
-                    PIKA_FORWARD(Receiver, receiver),
+                pika::execution::experimental::set_error(PIKA_FORWARD(Receiver, receiver),
                     std::make_exception_ptr(mpi_exception(mpi_status)));
             }
         }
 
         template <typename OperationState>
-        void set_value_request_callback_void(
-            MPI_Request request, OperationState& op_state)
+        void set_value_request_callback_void(MPI_Request request, OperationState& op_state)
         {
             detail::add_request_callback(
                 [&op_state](int status) mutable {
                     op_state.ts = {};
-                    set_value_request_callback_helper(
-                        status, PIKA_MOVE(op_state.receiver));
+                    set_value_request_callback_helper(status, PIKA_MOVE(op_state.receiver));
                 },
                 request, op_state.stream);
         }
 
         template <typename Result, typename OperationState>
-        void set_value_request_callback_non_void(
-            MPI_Request request, OperationState& op_state)
+        void set_value_request_callback_non_void(MPI_Request request, OperationState& op_state)
         {
             detail::add_request_callback(
                 [&op_state](int status) mutable {
                     op_state.ts = {};
-                    PIKA_ASSERT(
-                        std::holds_alternative<Result>(op_state.result));
-                    set_value_request_callback_helper(status,
-                        PIKA_MOVE(op_state.receiver),
+                    PIKA_ASSERT(std::holds_alternative<Result>(op_state.result));
+                    set_value_request_callback_helper(status, PIKA_MOVE(op_state.receiver),
                         PIKA_MOVE(std::get<Result>(op_state.result)));
                 },
                 request, op_state.stream);
@@ -79,14 +72,11 @@ namespace pika::mpi::experimental {
 
         template <typename F, typename... Ts>
         inline constexpr bool is_mpi_request_invocable_v =
-            std::is_invocable_v<F,
-                std::add_lvalue_reference_t<std::decay_t<Ts>>..., MPI_Request*>;
+            std::is_invocable_v<F, std::add_lvalue_reference_t<std::decay_t<Ts>>..., MPI_Request*>;
 
         template <typename F, typename... Ts>
-        using mpi_request_invoke_result_t =
-            std::decay_t<pika::util::detail::invoke_result_t<F,
-                std::add_lvalue_reference_t<std::decay_t<Ts>>...,
-                MPI_Request*>>;
+        using mpi_request_invoke_result_t = std::decay_t<std::invoke_result_t<F,
+            std::add_lvalue_reference_t<std::decay_t<Ts>>..., MPI_Request*>>;
 
         template <typename Sender, typename F>
         struct transform_mpi_sender_impl
@@ -95,32 +85,30 @@ namespace pika::mpi::experimental {
         };
 
         template <typename Sender, typename F>
-        using transform_mpi_sender = typename transform_mpi_sender_impl<Sender,
-            F>::transform_mpi_sender_type;
+        using transform_mpi_sender =
+            typename transform_mpi_sender_impl<Sender, F>::transform_mpi_sender_type;
 
         template <typename Sender, typename F>
         struct transform_mpi_sender_impl<Sender, F>::transform_mpi_sender_type
         {
+            using is_sender = void;
+
             std::decay_t<Sender> sender;
             std::decay_t<F> f;
             stream_type stream;
 
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
+#if defined(PIKA_HAVE_STDEXEC)
             template <typename... Ts>
             requires is_mpi_request_invocable_v<F, Ts...>
-            using invoke_result_helper =
-                pika::execution::experimental::completion_signatures<
-                    pika::execution::experimental::detail::
-                        result_type_signature_helper_t<
-                            mpi_request_invoke_result_t<F, Ts...>>>;
+            using invoke_result_helper = pika::execution::experimental::completion_signatures<
+                pika::execution::experimental::detail::result_type_signature_helper_t<
+                    mpi_request_invoke_result_t<F, Ts...>>>;
 
             using completion_signatures =
-                pika::execution::experimental::make_completion_signatures<
-                    std::decay_t<Sender>,
-                    pika::execution::experimental::detail::empty_env,
+                pika::execution::experimental::make_completion_signatures<std::decay_t<Sender>,
+                    pika::execution::experimental::empty_env,
                     pika::execution::experimental::completion_signatures<
-                        pika::execution::experimental::set_error_t(
-                            std::exception_ptr)>,
+                        pika::execution::experimental::set_error_t(std::exception_ptr)>,
                     invoke_result_helper>;
 #else
             template <typename Tuple>
@@ -132,24 +120,20 @@ namespace pika::mpi::experimental {
                 static_assert(is_mpi_request_invocable_v<F, Ts...>,
                     "F not invocable with the value_types specified.");
                 using result_type = mpi_request_invoke_result_t<F, Ts...>;
-                using type =
-                    std::conditional_t<std::is_void<result_type>::value,
-                        Tuple<>, Tuple<result_type>>;
+                using type = std::conditional_t<std::is_void<result_type>::value, Tuple<>,
+                    Tuple<result_type>>;
             };
 
-            template <template <typename...> class Tuple,
-                template <typename...> class Variant>
-            using value_types =
-                pika::util::detail::unique_t<pika::util::detail::transform_t<
-                    typename pika::execution::experimental::sender_traits<
-                        Sender>::template value_types<Tuple, Variant>,
-                    invoke_result_helper>>;
+            template <template <typename...> class Tuple, template <typename...> class Variant>
+            using value_types = pika::util::detail::unique_t<pika::util::detail::transform_t<
+                typename pika::execution::experimental::sender_traits<Sender>::template value_types<
+                    Tuple, Variant>,
+                invoke_result_helper>>;
 
             template <template <typename...> class Variant>
-            using error_types =
-                pika::util::detail::unique_t<pika::util::detail::prepend_t<
-                    typename pika::execution::experimental::sender_traits<
-                        Sender>::template error_types<Variant>,
+            using error_types = pika::util::detail::unique_t<
+                pika::util::detail::prepend_t<typename pika::execution::experimental::sender_traits<
+                                                  Sender>::template error_types<Variant>,
                     std::exception_ptr>>;
 
             static constexpr bool sends_done = false;
@@ -164,70 +148,58 @@ namespace pika::mpi::experimental {
 
                 struct transform_mpi_receiver
                 {
+                    using is_receiver = void;
+
                     operation_state& op_state;
 
                     template <typename Error>
-                    friend constexpr void
-                    tag_invoke(pika::execution::experimental::set_error_t,
+                    friend constexpr void tag_invoke(pika::execution::experimental::set_error_t,
                         transform_mpi_receiver&& r, Error&& error) noexcept
                     {
                         pika::execution::experimental::set_error(
-                            PIKA_MOVE(r.op_state.receiver),
-                            PIKA_FORWARD(Error, error));
+                            PIKA_MOVE(r.op_state.receiver), PIKA_FORWARD(Error, error));
                     }
 
-                    friend constexpr void tag_invoke(
-                        pika::execution::experimental::set_stopped_t,
+                    friend constexpr void tag_invoke(pika::execution::experimental::set_stopped_t,
                         transform_mpi_receiver&& r) noexcept
                     {
-                        pika::execution::experimental::set_stopped(
-                            PIKA_MOVE(r.op_state.receiver));
+                        pika::execution::experimental::set_stopped(PIKA_MOVE(r.op_state.receiver));
                     };
 
                     template <typename... Ts,
-                        typename = std::enable_if_t<
-                            is_mpi_request_invocable_v<F, Ts...>>>
-                    friend constexpr void
-                    tag_invoke(pika::execution::experimental::set_value_t,
+                        typename = std::enable_if_t<is_mpi_request_invocable_v<F, Ts...>>>
+                    friend constexpr void tag_invoke(pika::execution::experimental::set_value_t,
                         transform_mpi_receiver&& r, Ts&&... ts) noexcept
                     {
                         pika::detail::try_catch_exception_ptr(
                             [&]() mutable {
-                                using ts_element_type =
-                                    std::tuple<std::decay_t<Ts>...>;
+                                using ts_element_type = std::tuple<std::decay_t<Ts>...>;
                                 r.op_state.ts.template emplace<ts_element_type>(
                                     PIKA_FORWARD(Ts, ts)...);
-                                auto& t =
-                                    std::get<ts_element_type>(r.op_state.ts);
+                                auto& t = std::get<ts_element_type>(r.op_state.ts);
 
                                 MPI_Request request{MPI_REQUEST_NULL};
 
-                                using invoke_result_type =
-                                    mpi_request_invoke_result_t<F, Ts...>;
+                                using invoke_result_type = mpi_request_invoke_result_t<F, Ts...>;
 
                                 // throttle if too many "in flight"
                                 detail::wait_for_throttling(r.op_state.stream);
 
-                                if constexpr (std::is_void_v<
-                                                  invoke_result_type>)
+                                if constexpr (std::is_void_v<invoke_result_type>)
                                 {
                                     pika::util::detail::invoke_fused(
                                         [&](auto&... ts) mutable {
-                                            PIKA_INVOKE(PIKA_MOVE(r.op_state.f),
-                                                ts..., &request);
-                                            PIKA_ASSERT_MSG(
-                                                request != MPI_REQUEST_NULL,
-                                                "The MPI_Request is still "
-                                                "MPI_REQUEST_NULL after being "
-                                                "passed to the user callback "
-                                                "in transform_mpi. Did you "
-                                                "forget to use the request?");
+                                            PIKA_INVOKE(PIKA_MOVE(r.op_state.f), ts..., &request);
+                                            PIKA_ASSERT_MSG(request != MPI_REQUEST_NULL,
+                                                "The MPI_Request is still MPI_REQUEST_NULL after "
+                                                "being passed to the user callback in "
+                                                "transform_mpi. Did you forget to use the "
+                                                "request?");
 
                                             // When the return type is void,
                                             // there is no value to forward to
                                             // the receiver
-                                            set_value_request_callback_void(
-                                                request, r.op_state);
+                                            set_value_request_callback_void(request, r.op_state);
                                         },
                                         t);
                                 }
@@ -235,23 +207,19 @@ namespace pika::mpi::experimental {
                                 {
                                     pika::util::detail::invoke_fused(
                                         [&](auto&... ts) mutable {
-                                            r.op_state.result.template emplace<
-                                                invoke_result_type>(PIKA_INVOKE(
-                                                PIKA_MOVE(r.op_state.f), ts...,
-                                                &request));
-                                            PIKA_ASSERT_MSG(
-                                                request != MPI_REQUEST_NULL,
-                                                "The MPI_Request is still "
-                                                "MPI_REQUEST_NULL after being "
-                                                "passed to the user callback "
-                                                "in transform_mpi. Did you "
-                                                "forget to use the request?");
+                                            r.op_state.result.template emplace<invoke_result_type>(
+                                                PIKA_INVOKE(
+                                                    PIKA_MOVE(r.op_state.f), ts..., &request));
+                                            PIKA_ASSERT_MSG(request != MPI_REQUEST_NULL,
+                                                "The MPI_Request is still MPI_REQUEST_NULL after "
+                                                "being passed to the user callback in "
+                                                "transform_mpi. Did you forget to use the "
+                                                "request?");
 
                                             // When the return type is non-void,
                                             // we have to forward the value to
                                             // the receiver
-                                            set_value_request_callback_non_void<
-                                                invoke_result_type>(
+                                            set_value_request_callback_non_void<invoke_result_type>(
                                                 request, r.op_state);
                                         },
                                         t);
@@ -259,48 +227,42 @@ namespace pika::mpi::experimental {
                             },
                             [&](std::exception_ptr ep) {
                                 pika::execution::experimental::set_error(
-                                    PIKA_MOVE(r.op_state.receiver),
-                                    PIKA_MOVE(ep));
+                                    PIKA_MOVE(r.op_state.receiver), PIKA_MOVE(ep));
                             });
                     }
 
-                    friend constexpr pika::execution::experimental::detail::
-                        empty_env
-                        tag_invoke(pika::execution::experimental::get_env_t,
-                            transform_mpi_receiver const&) noexcept
+                    friend constexpr pika::execution::experimental::empty_env tag_invoke(
+                        pika::execution::experimental::get_env_t,
+                        transform_mpi_receiver const&) noexcept
                     {
                         return {};
                     }
                 };
 
                 using operation_state_type =
-                    pika::execution::experimental::connect_result_t<
-                        std::decay_t<Sender>, transform_mpi_receiver>;
+                    pika::execution::experimental::connect_result_t<std::decay_t<Sender>,
+                        transform_mpi_receiver>;
                 operation_state_type op_state;
 
                 template <typename Tuple>
                 struct value_types_helper
                 {
-                    using type =
-                        pika::util::detail::transform_t<Tuple, std::decay>;
+                    using type = pika::util::detail::transform_t<Tuple, std::decay>;
                 };
 
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
+#if defined(PIKA_HAVE_STDEXEC)
                 using ts_type = pika::util::detail::prepend_t<
                     pika::util::detail::transform_t<
-                        pika::execution::experimental::value_types_of_t<
-                            std::decay_t<Sender>,
-                            pika::execution::experimental::detail::empty_env,
-                            std::tuple, pika::detail::variant>,
+                        pika::execution::experimental::value_types_of_t<std::decay_t<Sender>,
+                            pika::execution::experimental::empty_env, std::tuple,
+                            pika::detail::variant>,
                         value_types_helper>,
                     pika::detail::monostate>;
 #else
                 using ts_type = pika::util::detail::prepend_t<
                     pika::util::detail::transform_t<
-                        typename pika::execution::experimental::sender_traits<
-                            std::decay_t<Sender>>::
-                            template value_types<std::tuple,
-                                pika::detail::variant>,
+                        typename pika::execution::experimental::sender_traits<std::decay_t<
+                            Sender>>::template value_types<std::tuple, pika::detail::variant>,
                         value_types_helper>,
                     pika::detail::monostate>;
 #endif
@@ -335,26 +297,20 @@ namespace pika::mpi::experimental {
                 {
                     using type = pika::detail::monostate;
                 };
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
-                using result_type = pika::util::detail::change_pack_t<
-                    pika::detail::variant,
+#if defined(PIKA_HAVE_STDEXEC)
+                using result_type = pika::util::detail::change_pack_t<pika::detail::variant,
                     pika::util::detail::unique_t<pika::util::detail::prepend_t<
                         pika::util::detail::transform_t<
                             pika::execution::experimental::value_types_of_t<
-                                transform_mpi_sender_type,
-                                pika::execution::experimental::detail::
-                                    empty_env,
-                                pika::util::detail::pack,
-                                pika::util::detail::pack>,
+                                transform_mpi_sender_type, pika::execution::experimental::empty_env,
+                                pika::util::detail::pack, pika::util::detail::pack>,
                             result_types_helper>,
                         pika::detail::monostate>>>;
 #else
-                using result_type = pika::util::detail::change_pack_t<
-                    pika::detail::variant,
+                using result_type = pika::util::detail::change_pack_t<pika::detail::variant,
                     pika::util::detail::unique_t<pika::util::detail::prepend_t<
                         pika::util::detail::transform_t<
-                            transform_mpi_sender_type::value_types<
-                                pika::util::detail::pack,
+                            transform_mpi_sender_type::value_types<pika::util::detail::pack,
                                 pika::util::detail::pack>,
                             result_types_helper>,
                         pika::detail::monostate>>>;
@@ -362,41 +318,35 @@ namespace pika::mpi::experimental {
                 result_type result;
 
                 template <typename Receiver_, typename F_, typename Sender_>
-                operation_state(Receiver_&& receiver, F_&& f, Sender_&& sender,
-                    stream_type s)
+                operation_state(Receiver_&& receiver, F_&& f, Sender_&& sender, stream_type s)
                   : receiver(PIKA_FORWARD(Receiver_, receiver))
                   , f(PIKA_FORWARD(F_, f))
                   , stream{s}
                   , op_state(pika::execution::experimental::connect(
-                        PIKA_FORWARD(Sender_, sender),
-                        transform_mpi_receiver{*this}))
+                        PIKA_FORWARD(Sender_, sender), transform_mpi_receiver{*this}))
                 {
                 }
 
                 friend constexpr auto tag_invoke(
-                    pika::execution::experimental::start_t,
-                    operation_state& os) noexcept
+                    pika::execution::experimental::start_t, operation_state& os) noexcept
                 {
                     return pika::execution::experimental::start(os.op_state);
                 }
             };
 
             template <typename Receiver>
-            friend constexpr auto
-            tag_invoke(pika::execution::experimental::connect_t,
-                transform_mpi_sender_type& s, Receiver&& receiver)
+            friend constexpr auto tag_invoke(pika::execution::experimental::connect_t,
+                transform_mpi_sender_type const& s, Receiver&& receiver)
             {
                 return operation_state<Receiver>(
                     PIKA_FORWARD(Receiver, receiver), s.f, s.sender, s.stream);
             }
 
             template <typename Receiver>
-            friend constexpr auto
-            tag_invoke(pika::execution::experimental::connect_t,
+            friend constexpr auto tag_invoke(pika::execution::experimental::connect_t,
                 transform_mpi_sender_type&& s, Receiver&& receiver)
             {
-                return operation_state<Receiver>(
-                    PIKA_FORWARD(Receiver, receiver), PIKA_MOVE(s.f),
+                return operation_state<Receiver>(PIKA_FORWARD(Receiver, receiver), PIKA_MOVE(s.f),
                     PIKA_MOVE(s.sender), s.stream);
             }
         };
@@ -408,11 +358,9 @@ namespace pika::mpi::experimental {
     private:
         template <typename Sender, typename F,
             PIKA_CONCEPT_REQUIRES_(
-                pika::execution::experimental::is_sender_v<Sender>)>
-        friend constexpr PIKA_FORCEINLINE auto
-        tag_fallback_invoke(transform_mpi_t, Sender&& sender, F&& f,
-            mpi::experimental::stream_type s =
-                mpi::experimental::stream_type::automatic)
+                pika::execution::experimental::is_sender_v<std::decay_t<Sender>>)>
+        friend constexpr PIKA_FORCEINLINE auto tag_fallback_invoke(transform_mpi_t, Sender&& sender,
+            F&& f, mpi::experimental::stream_type s = mpi::experimental::stream_type::automatic)
         {
             return transform_mpi_detail::transform_mpi_sender<Sender, F>{
                 PIKA_FORWARD(Sender, sender), PIKA_FORWARD(F, f), s};
@@ -422,14 +370,11 @@ namespace pika::mpi::experimental {
         // tag invoke overload for mpi_transform
         //
         template <typename F>
-        friend constexpr PIKA_FORCEINLINE auto
-        tag_fallback_invoke(transform_mpi_t, F&& f,
-            mpi::experimental::stream_type s =
-                mpi::experimental::stream_type::automatic)
+        friend constexpr PIKA_FORCEINLINE auto tag_fallback_invoke(transform_mpi_t, F&& f,
+            mpi::experimental::stream_type s = mpi::experimental::stream_type::automatic)
         {
-            return ::pika::execution::experimental::detail::partial_algorithm<
-                transform_mpi_t, F, mpi::experimental::stream_type>{
-                PIKA_FORWARD(F, f), s};
+            return ::pika::execution::experimental::detail::partial_algorithm<transform_mpi_t, F,
+                mpi::experimental::stream_type>{PIKA_FORWARD(F, f), s};
         }
 
     } transform_mpi{};
