@@ -91,8 +91,7 @@ namespace pika::threads::coroutines {
 
             void* allocate(std::size_t size) const
             {
-# if defined(_POSIX_VERSION) &&                                                                    \
-     !(defined(__APPLE__) && (defined(arm64) || defined(__arm64) || defined(__arm64__)))
+# if defined(_POSIX_VERSION)
                 void* limit = posix::alloc_stack(size);
                 posix::watermark_stack(limit, size);
 # else
