@@ -9,19 +9,18 @@
 #include <pika/config.hpp>
 
 #if defined(PIKA_HAVE_STACKTRACES)
-#include <pika/debugging/backtrace/backtrace.hpp>
+# include <pika/debugging/backtrace/backtrace.hpp>
 #else
 
-#include <cstddef>
-#include <string>
+# include <cstddef>
+# include <string>
 
 namespace pika::debug::detail {
     class backtrace
     {
     };
 
-    inline std::string trace(
-        std::size_t frames_no = PIKA_HAVE_THREAD_BACKTRACE_DEPTH)
+    inline std::string trace(std::size_t frames_no = PIKA_HAVE_THREAD_BACKTRACE_DEPTH)
     {
         return "";
     }
