@@ -8,14 +8,14 @@
 
 #include <pika/config.hpp>
 
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
-#include <pika/execution_base/p2300_forward.hpp>
+#if defined(PIKA_HAVE_STDEXEC)
+# include <pika/execution_base/stdexec_forward.hpp>
 #else
-#include <pika/execution/algorithms/just.hpp>
-#include <pika/execution/algorithms/transfer.hpp>
-#include <pika/functional/detail/tag_fallback_invoke.hpp>
+# include <pika/execution/algorithms/just.hpp>
+# include <pika/execution/algorithms/transfer.hpp>
+# include <pika/functional/detail/tag_fallback_invoke.hpp>
 
-#include <utility>
+# include <utility>
 
 namespace pika::execution::experimental {
     inline constexpr struct transfer_just_t final
@@ -26,8 +26,7 @@ namespace pika::execution::experimental {
         friend constexpr PIKA_FORCEINLINE auto
         tag_fallback_invoke(transfer_just_t, Scheduler&& scheduler, Ts&&... ts)
         {
-            return transfer(just(PIKA_FORWARD(Ts, ts)...),
-                PIKA_FORWARD(Scheduler, scheduler));
+            return transfer(just(PIKA_FORWARD(Ts, ts)...), PIKA_FORWARD(Scheduler, scheduler));
         }
     } transfer_just{};
 }    // namespace pika::execution::experimental
