@@ -15,14 +15,12 @@
 ///////////////////////////////////////////////////////////////////////////////
 namespace pika::parallel::execution::detail {
     /// \cond NOINTERNAL
-    using get_os_thread_count_type =
-        pika::util::detail::function<std::size_t()>;
+    using get_os_thread_count_type = pika::util::detail::function<std::size_t()>;
     PIKA_EXPORT void set_get_os_thread_count(get_os_thread_count_type f);
     PIKA_EXPORT std::size_t get_os_thread_count();
 
-    using get_pu_mask_type =
-        pika::util::detail::function<threads::detail::mask_cref_type(
-            threads::detail::topology&, std::size_t)>;
+    using get_pu_mask_type = pika::util::detail::function<threads::detail::mask_cref_type(
+        threads::detail::topology&, std::size_t)>;
     PIKA_EXPORT void set_get_pu_mask(get_pu_mask_type f);
     PIKA_EXPORT threads::detail::mask_cref_type get_pu_mask(
         threads::detail::topology&, std::size_t);
