@@ -27,8 +27,8 @@ struct scheduler_schedule_from
     std::reference_wrapper<std::atomic<bool>> tag_invoke_overload_called;
 
     template <typename F>
-    friend void tag_invoke(pika::execution::experimental::execute_t,
-        scheduler_schedule_from s, F&& f)
+    friend void
+    tag_invoke(pika::execution::experimental::execute_t, scheduler_schedule_from s, F&& f)
     {
         s.execute_called.get() = true;
         PIKA_INVOKE(std::forward<F>(f), );
@@ -40,8 +40,7 @@ struct scheduler_schedule_from
         std::reference_wrapper<std::atomic<bool>> execute_called;
         std::reference_wrapper<std::atomic<bool>> tag_invoke_overload_called;
 
-        template <template <class...> class Tuple,
-            template <class...> class Variant>
+        template <template <class...> class Tuple, template <class...> class Variant>
         using value_types = Variant<Tuple<>>;
 
         template <template <class...> class Variant>
@@ -49,25 +48,23 @@ struct scheduler_schedule_from
 
         static constexpr bool sends_done = false;
 
-        using completion_signatures =
-            pika::execution::experimental::completion_signatures<
-                pika::execution::experimental::set_value_t()>;
+        using completion_signatures = pika::execution::experimental::completion_signatures<
+            pika::execution::experimental::set_value_t()>;
 
         template <typename R>
         struct operation_state
         {
             std::decay_t<R> r;
 
-            friend void tag_invoke(pika::execution::experimental::start_t,
-                operation_state& os) noexcept
+            friend void tag_invoke(
+                pika::execution::experimental::start_t, operation_state& os) noexcept
             {
                 pika::execution::experimental::set_value(std::move(os.r));
             };
         };
 
         template <typename R>
-        friend auto
-        tag_invoke(pika::execution::experimental::connect_t, sender&&, R&& r)
+        friend auto tag_invoke(pika::execution::experimental::connect_t, sender&&, R&& r)
         {
             return operation_state<R>{std::forward<R>(r)};
         }
@@ -77,17 +74,14 @@ struct scheduler_schedule_from
                 pika::execution::experimental::set_value_t>,
             sender const& s) noexcept
         {
-            return {s.schedule_called, s.execute_called,
-                s.tag_invoke_overload_called};
+            return {s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
         }
     };
 
-    friend sender tag_invoke(
-        pika::execution::experimental::schedule_t, scheduler_schedule_from s)
+    friend sender tag_invoke(pika::execution::experimental::schedule_t, scheduler_schedule_from s)
     {
         s.schedule_called.get() = true;
-        return {
-            s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
+        return {s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
     }
 
     bool operator==(scheduler_schedule_from const&) const noexcept
@@ -105,8 +99,8 @@ template <typename Sender>
 auto tag_invoke(ex::schedule_from_t, scheduler_schedule_from sched, Sender&&)
 {
     sched.tag_invoke_overload_called.get() = true;
-    return scheduler_schedule_from::sender{sched.schedule_called,
-        sched.execute_called, sched.tag_invoke_overload_called};
+    return scheduler_schedule_from::sender{
+        sched.schedule_called, sched.execute_called, sched.tag_invoke_overload_called};
 }
 
 // transfer customization
@@ -117,8 +111,7 @@ struct scheduler_transfer
     std::reference_wrapper<std::atomic<bool>> tag_invoke_overload_called;
 
     template <typename F>
-    friend void tag_invoke(
-        pika::execution::experimental::execute_t, scheduler_transfer s, F&& f)
+    friend void tag_invoke(pika::execution::experimental::execute_t, scheduler_transfer s, F&& f)
     {
         s.execute_called.get() = true;
         PIKA_INVOKE(std::forward<F>(f), );
@@ -130,8 +123,7 @@ struct scheduler_transfer
         std::reference_wrapper<std::atomic<bool>> execute_called;
         std::reference_wrapper<std::atomic<bool>> tag_invoke_overload_called;
 
-        template <template <class...> class Tuple,
-            template <class...> class Variant>
+        template <template <class...> class Tuple, template <class...> class Variant>
         using value_types = Variant<Tuple<>>;
 
         template <template <class...> class Variant>
@@ -139,25 +131,23 @@ struct scheduler_transfer
 
         static constexpr bool sends_done = false;
 
-        using completion_signatures =
-            pika::execution::experimental::completion_signatures<
-                pika::execution::experimental::set_value_t()>;
+        using completion_signatures = pika::execution::experimental::completion_signatures<
+            pika::execution::experimental::set_value_t()>;
 
         template <typename R>
         struct operation_state
         {
             std::decay_t<R> r;
 
-            friend void tag_invoke(pika::execution::experimental::start_t,
-                operation_state& os) noexcept
+            friend void tag_invoke(
+                pika::execution::experimental::start_t, operation_state& os) noexcept
             {
                 pika::execution::experimental::set_value(std::move(os.r));
             };
         };
 
         template <typename R>
-        friend auto
-        tag_invoke(pika::execution::experimental::connect_t, sender&&, R&& r)
+        friend auto tag_invoke(pika::execution::experimental::connect_t, sender&&, R&& r)
         {
             return operation_state<R>{std::forward<R>(r)};
         }
@@ -167,17 +157,14 @@ struct scheduler_transfer
                 pika::execution::experimental::set_value_t>,
             sender const& s) noexcept
         {
-            return {s.schedule_called, s.execute_called,
-                s.tag_invoke_overload_called};
+            return {s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
         }
     };
 
-    friend sender tag_invoke(
-        pika::execution::experimental::schedule_t, scheduler_transfer s)
+    friend sender tag_invoke(pika::execution::experimental::schedule_t, scheduler_transfer s)
     {
         s.schedule_called.get() = true;
-        return {
-            s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
+        return {s.schedule_called, s.execute_called, s.tag_invoke_overload_called};
     }
 
     bool operator==(scheduler_transfer const&) const noexcept
@@ -192,12 +179,11 @@ struct scheduler_transfer
 };
 
 template <typename Sender, typename Scheduler>
-decltype(auto) tag_invoke(ex::transfer_t, scheduler_transfer completion_sched,
-    Sender&& sender, Scheduler&& sched)
+decltype(auto)
+tag_invoke(ex::transfer_t, scheduler_transfer completion_sched, Sender&& sender, Scheduler&& sched)
 {
     completion_sched.tag_invoke_overload_called.get() = true;
-    return ex::schedule_from(
-        std::forward<Scheduler>(sched), std::forward<Sender>(sender));
+    return ex::schedule_from(std::forward<Scheduler>(sched), std::forward<Sender>(sender));
 }
 
 struct sender_with_completion_scheduler : void_sender
@@ -209,11 +195,20 @@ struct sender_with_completion_scheduler : void_sender
     {
     }
 
-    friend scheduler_transfer tag_invoke(
-        ex::get_completion_scheduler_t<ex::set_value_t>,
-        sender_with_completion_scheduler s) noexcept
+    struct env
     {
-        return s.sched;
+        scheduler_transfer scheduler;
+
+        friend scheduler_transfer tag_invoke(
+            ex::get_completion_scheduler_t<ex::set_value_t>, env const& e) noexcept
+        {
+            return e.scheduler;
+        }
+    };
+
+    friend env tag_invoke(ex::get_env_t, sender_with_completion_scheduler const& s)
+    {
+        return {s.sched};
     }
 };
 
@@ -226,8 +221,8 @@ int main()
         std::atomic<bool> scheduler_execute_called{false};
         std::atomic<bool> tag_invoke_overload_called{false};
         auto s = ex::transfer(ex::just(),
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [] {};
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -244,8 +239,8 @@ int main()
         std::atomic<bool> scheduler_execute_called{false};
         std::atomic<bool> tag_invoke_overload_called{false};
         auto s = ex::transfer(ex::just(3),
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](int x) { PIKA_TEST_EQ(x, 3); };
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -263,8 +258,8 @@ int main()
         std::atomic<bool> tag_invoke_overload_called{false};
         int x = 3;
         auto s = ex::transfer(const_reference_sender<decltype(x)>{x},
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](int x) { PIKA_TEST_EQ(x, 3); };
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -280,10 +275,9 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> scheduler_execute_called{false};
         std::atomic<bool> tag_invoke_overload_called{false};
-        auto s =
-            ex::transfer(ex::just(custom_type_non_default_constructible{42}),
-                scheduler{scheduler_schedule_called, scheduler_execute_called,
-                    tag_invoke_overload_called});
+        auto s = ex::transfer(ex::just(custom_type_non_default_constructible{42}),
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](auto x) { PIKA_TEST_EQ(x.x, 42); };
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -299,10 +293,9 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> scheduler_execute_called{false};
         std::atomic<bool> tag_invoke_overload_called{false};
-        auto s = ex::transfer(
-            ex::just(custom_type_non_default_constructible_non_copyable{42}),
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+        auto s = ex::transfer(ex::just(custom_type_non_default_constructible_non_copyable{42}),
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](auto x) { PIKA_TEST_EQ(x.x, 42); };
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -319,8 +312,8 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> tag_invoke_overload_called{false};
         auto s = ex::transfer(ex::just(std::string("hello"), 3),
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](std::string s, int x) {
             PIKA_TEST_EQ(s, std::string("hello"));
             PIKA_TEST_EQ(x, 3);
@@ -341,8 +334,8 @@ int main()
         std::atomic<bool> tag_invoke_overload_called{false};
         int x = 3;
         auto s = ex::transfer(const_reference_sender<int>{x},
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](int x) { PIKA_TEST_EQ(x, 3); };
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -360,8 +353,8 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> tag_invoke_overload_called{false};
         auto s = ex::just(std::string("hello"), 3) |
-            ex::transfer(scheduler{scheduler_schedule_called,
-                scheduler_execute_called, tag_invoke_overload_called});
+            ex::transfer(scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [](std::string s, int x) {
             PIKA_TEST_EQ(s, std::string("hello"));
             PIKA_TEST_EQ(x, 3);
@@ -382,8 +375,8 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> scheduler_execute_called{false};
         auto s = ex::transfer(ex::just(),
-            scheduler_schedule_from{scheduler_schedule_called,
-                scheduler_execute_called, tag_invoke_overload_called});
+            scheduler_schedule_from{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto f = [] {};
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -399,22 +392,18 @@ int main()
         std::atomic<bool> source_scheduler_tag_invoke_overload_called{false};
         std::atomic<bool> source_scheduler_schedule_called{false};
         std::atomic<bool> source_scheduler_execute_called{false};
-        std::atomic<bool> destination_scheduler_tag_invoke_overload_called{
-            false};
+        std::atomic<bool> destination_scheduler_tag_invoke_overload_called{false};
         std::atomic<bool> destination_scheduler_schedule_called{false};
         std::atomic<bool> destination_scheduler_execute_called{false};
 
         scheduler_transfer source_scheduler{source_scheduler_schedule_called,
-            source_scheduler_execute_called,
-            source_scheduler_tag_invoke_overload_called};
+            source_scheduler_execute_called, source_scheduler_tag_invoke_overload_called};
         scheduler destination_scheduler{
-            scheduler{destination_scheduler_schedule_called,
-                destination_scheduler_execute_called,
+            scheduler{destination_scheduler_schedule_called, destination_scheduler_execute_called,
                 destination_scheduler_tag_invoke_overload_called}};
 
         auto s = ex::transfer(
-            sender_with_completion_scheduler{std::move(source_scheduler)},
-            destination_scheduler);
+            sender_with_completion_scheduler{std::move(source_scheduler)}, destination_scheduler);
         auto f = [] {};
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -433,22 +422,17 @@ int main()
         std::atomic<bool> source_scheduler_tag_invoke_overload_called{false};
         std::atomic<bool> source_scheduler_schedule_called{false};
         std::atomic<bool> source_scheduler_execute_called{false};
-        std::atomic<bool> destination_scheduler_tag_invoke_overload_called{
-            false};
+        std::atomic<bool> destination_scheduler_tag_invoke_overload_called{false};
         std::atomic<bool> destination_scheduler_schedule_called{false};
         std::atomic<bool> destination_scheduler_execute_called{false};
 
         scheduler_transfer source_scheduler{source_scheduler_schedule_called,
-            source_scheduler_execute_called,
-            source_scheduler_tag_invoke_overload_called};
-        scheduler_schedule_from destination_scheduler{
-            destination_scheduler_schedule_called,
-            destination_scheduler_execute_called,
-            destination_scheduler_tag_invoke_overload_called};
+            source_scheduler_execute_called, source_scheduler_tag_invoke_overload_called};
+        scheduler_schedule_from destination_scheduler{destination_scheduler_schedule_called,
+            destination_scheduler_execute_called, destination_scheduler_tag_invoke_overload_called};
 
         auto s = ex::transfer(
-            sender_with_completion_scheduler{std::move(source_scheduler)},
-            destination_scheduler);
+            sender_with_completion_scheduler{std::move(source_scheduler)}, destination_scheduler);
         auto f = [] {};
         auto r = callback_receiver<decltype(f)>{f, set_value_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -469,8 +453,8 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> scheduler_execute_called{false};
         auto s = ex::transfer(error_sender{},
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto r = error_callback_receiver<decltype(check_exception_ptr)>{
             check_exception_ptr, set_error_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -483,7 +467,7 @@ int main()
         // implementation puts in more effort call set_error on the scheduler's
         // context, but it can't be guaranteed in all cases which is why
         // transfer doesn't provide a completion scheduler for set_error.
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
+#if defined(PIKA_HAVE_STDEXEC)
         PIKA_TEST(scheduler_schedule_called);
 #else
         PIKA_TEST(!scheduler_schedule_called);
@@ -497,8 +481,8 @@ int main()
         std::atomic<bool> scheduler_schedule_called{false};
         std::atomic<bool> scheduler_execute_called{false};
         auto s = ex::transfer(const_reference_error_sender{},
-            scheduler{scheduler_schedule_called, scheduler_execute_called,
-                tag_invoke_overload_called});
+            scheduler{
+                scheduler_schedule_called, scheduler_execute_called, tag_invoke_overload_called});
         auto r = error_callback_receiver<decltype(check_exception_ptr)>{
             check_exception_ptr, set_error_called};
         auto os = ex::connect(std::move(s), std::move(r));
@@ -511,7 +495,7 @@ int main()
         // implementation puts in more effort call set_error on the scheduler's
         // context, but it can't be guaranteed in all cases which is why
         // transfer doesn't provide a completion scheduler for set_error.
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
+#if defined(PIKA_HAVE_STDEXEC)
         PIKA_TEST(scheduler_schedule_called);
 #else
         PIKA_TEST(!scheduler_schedule_called);
