@@ -12,11 +12,10 @@
 //
 
 #if defined(PIKA_MSVC)
-#pragma warning(disable : 4786)    // identifier truncated in debug info
-#pragma warning(disable : 4710)    // function not inlined
-#pragma warning(                                                               \
-    disable : 4711)    // function selected for automatic inline expansion
-#pragma warning(disable : 4514)    // unreferenced inline removed
+# pragma warning(disable : 4786)    // identifier truncated in debug info
+# pragma warning(disable : 4710)    // function not inlined
+# pragma warning(disable : 4711)    // function selected for automatic inline expansion
+# pragma warning(disable : 4514)    // unreferenced inline removed
 #endif
 
 #include <pika/functional/bind.hpp>
@@ -55,9 +54,7 @@ int main()
 {
     Y y;
 
-    PIKA_TEST_EQ(
-        pika::util::detail::bind(&X::f, pika::util::detail::bind(&Y::f, &y))(),
-        42);
+    PIKA_TEST_EQ(pika::util::detail::bind(&X::f, pika::util::detail::bind(&Y::f, &y))(), 42);
 
     return 0;
 }
