@@ -13,11 +13,10 @@
 //
 
 #if defined(PIKA_MSVC)
-#pragma warning(disable : 4786)    // identifier truncated in debug info
-#pragma warning(disable : 4710)    // function not inlined
-#pragma warning(                                                               \
-    disable : 4711)    // function selected for automatic inline expansion
-#pragma warning(disable : 4514)    // unreferenced inline removed
+# pragma warning(disable : 4786)    // identifier truncated in debug info
+# pragma warning(disable : 4710)    // function not inlined
+# pragma warning(disable : 4711)    // function selected for automatic inline expansion
+# pragma warning(disable : 4514)    // unreferenced inline removed
 #endif
 
 #include <pika/functional/bind.hpp>
@@ -67,20 +66,18 @@ long f_6(long a, long b, long c, long d, long e, long f)
 
 long f_7(long a, long b, long c, long d, long e, long f, long g)
 {
-    return a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f +
-        1000000 * g;
+    return a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g;
 }
 
 long f_8(long a, long b, long c, long d, long e, long f, long g, long h)
 {
-    return a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f +
-        1000000 * g + 10000000 * h;
+    return a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g + 10000000 * h;
 }
 
 long f_9(long a, long b, long c, long d, long e, long f, long g, long h, long i)
 {
-    return a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f +
-        1000000 * g + 10000000 * h + 100000000 * i;
+    return a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g + 10000000 * h +
+        100000000 * i;
 }
 
 long global_result;
@@ -122,21 +119,19 @@ void fv_6(long a, long b, long c, long d, long e, long f)
 
 void fv_7(long a, long b, long c, long d, long e, long f, long g)
 {
-    global_result =
-        a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g;
+    global_result = a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g;
 }
 
 void fv_8(long a, long b, long c, long d, long e, long f, long g, long h)
 {
-    global_result = a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f +
-        1000000 * g + 10000000 * h;
+    global_result =
+        a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g + 10000000 * h;
 }
 
-void fv_9(
-    long a, long b, long c, long d, long e, long f, long g, long h, long i)
+void fv_9(long a, long b, long c, long d, long e, long f, long g, long h, long i)
 {
-    global_result = a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f +
-        1000000 * g + 10000000 * h + 100000000 * i;
+    global_result = a + 10 * b + 100 * c + 1000 * d + 10000 * e + 100000 * f + 1000000 * g +
+        10000000 * h + 100000000 * i;
 }
 
 void function_test()
@@ -147,41 +142,29 @@ void function_test()
     PIKA_TEST(pika::util::detail::bind(f_1, placeholders::_1)(i) == 1L);
     PIKA_TEST(pika::util::detail::bind(f_2, placeholders::_1, 2)(i) == 21L);
     PIKA_TEST(pika::util::detail::bind(f_3, placeholders::_1, 2, 3)(i) == 321L);
+    PIKA_TEST(pika::util::detail::bind(f_4, placeholders::_1, 2, 3, 4)(i) == 4321L);
+    PIKA_TEST(pika::util::detail::bind(f_5, placeholders::_1, 2, 3, 4, 5)(i) == 54321L);
+    PIKA_TEST(pika::util::detail::bind(f_6, placeholders::_1, 2, 3, 4, 5, 6)(i) == 654321L);
+    PIKA_TEST(pika::util::detail::bind(f_7, placeholders::_1, 2, 3, 4, 5, 6, 7)(i) == 7654321L);
+    PIKA_TEST(pika::util::detail::bind(f_8, placeholders::_1, 2, 3, 4, 5, 6, 7, 8)(i) == 87654321L);
     PIKA_TEST(
-        pika::util::detail::bind(f_4, placeholders::_1, 2, 3, 4)(i) == 4321L);
-    PIKA_TEST(pika::util::detail::bind(f_5, placeholders::_1, 2, 3, 4, 5)(i) ==
-        54321L);
-    PIKA_TEST(pika::util::detail::bind(f_6, placeholders::_1, 2, 3, 4, 5, 6)(
-                  i) == 654321L);
-    PIKA_TEST(pika::util::detail::bind(f_7, placeholders::_1, 2, 3, 4, 5, 6, 7)(
-                  i) == 7654321L);
-    PIKA_TEST(pika::util::detail::bind(
-                  f_8, placeholders::_1, 2, 3, 4, 5, 6, 7, 8)(i) == 87654321L);
-    PIKA_TEST(pika::util::detail::bind(f_9, placeholders::_1, 2, 3, 4, 5, 6, 7,
-                  8, 9)(i) == 987654321L);
+        pika::util::detail::bind(f_9, placeholders::_1, 2, 3, 4, 5, 6, 7, 8, 9)(i) == 987654321L);
 
     PIKA_TEST((pika::util::detail::bind(fv_0)(i), (global_result == 17041L)));
-    PIKA_TEST((pika::util::detail::bind(fv_1, placeholders::_1)(i),
-        (global_result == 1L)));
-    PIKA_TEST((pika::util::detail::bind(fv_2, placeholders::_1, 2)(i),
-        (global_result == 21L)));
-    PIKA_TEST((pika::util::detail::bind(fv_3, placeholders::_1, 2, 3)(i),
-        (global_result == 321L)));
-    PIKA_TEST((pika::util::detail::bind(fv_4, placeholders::_1, 2, 3, 4)(i),
-        (global_result == 4321L)));
+    PIKA_TEST((pika::util::detail::bind(fv_1, placeholders::_1)(i), (global_result == 1L)));
+    PIKA_TEST((pika::util::detail::bind(fv_2, placeholders::_1, 2)(i), (global_result == 21L)));
+    PIKA_TEST((pika::util::detail::bind(fv_3, placeholders::_1, 2, 3)(i), (global_result == 321L)));
+    PIKA_TEST(
+        (pika::util::detail::bind(fv_4, placeholders::_1, 2, 3, 4)(i), (global_result == 4321L)));
     PIKA_TEST((pika::util::detail::bind(fv_5, placeholders::_1, 2, 3, 4, 5)(i),
         (global_result == 54321L)));
-    PIKA_TEST(
-        (pika::util::detail::bind(fv_6, placeholders::_1, 2, 3, 4, 5, 6)(i),
-            (global_result == 654321L)));
-    PIKA_TEST(
-        (pika::util::detail::bind(fv_7, placeholders::_1, 2, 3, 4, 5, 6, 7)(i),
-            (global_result == 7654321L)));
-    PIKA_TEST((pika::util::detail::bind(
-                   fv_8, placeholders::_1, 2, 3, 4, 5, 6, 7, 8)(i),
+    PIKA_TEST((pika::util::detail::bind(fv_6, placeholders::_1, 2, 3, 4, 5, 6)(i),
+        (global_result == 654321L)));
+    PIKA_TEST((pika::util::detail::bind(fv_7, placeholders::_1, 2, 3, 4, 5, 6, 7)(i),
+        (global_result == 7654321L)));
+    PIKA_TEST((pika::util::detail::bind(fv_8, placeholders::_1, 2, 3, 4, 5, 6, 7, 8)(i),
         (global_result == 87654321L)));
-    PIKA_TEST((pika::util::detail::bind(
-                   fv_9, placeholders::_1, 2, 3, 4, 5, 6, 7, 8, 9)(i),
+    PIKA_TEST((pika::util::detail::bind(fv_9, placeholders::_1, 2, 3, 4, 5, 6, 7, 8, 9)(i),
         (global_result == 987654321L)));
 }
 
@@ -250,7 +233,7 @@ void function_object_test2()
 
 //
 
-#if !defined(BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) &&                      \
+#if !defined(BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) &&                                          \
     !defined(BOOST_NO_FUNCTION_TEMPLATE_ORDERING)
 
 struct Z
@@ -491,8 +474,7 @@ struct V
         f7(a1, a2, a3, a4, a5, a6, a7);
         f1(a8);
     }
-    void g8(
-        int a1, int a2, int a3, int a4, int a5, int a6, int a7, int a8) const
+    void g8(int a1, int a2, int a3, int a4, int a5, int a6, int a7, int a8) const
     {
         g7(a1, a2, a3, a4, a5, a6, a7);
         g1(a8);
@@ -684,34 +666,25 @@ void nested_bind_test()
     int const x = 1;
     int const y = 2;
 
-    PIKA_TEST(pika::util::detail::bind(f_1,
-                  pika::util::detail::bind(f_1, placeholders::_1))(x) == 1L);
-    PIKA_TEST(pika::util::detail::bind(f_1,
-                  pika::util::detail::bind(
-                      f_2, placeholders::_1, placeholders::_2))(x, y) == 21L);
-    PIKA_TEST(pika::util::detail::bind(f_2,
-                  pika::util::detail::bind(f_1, placeholders::_1),
-                  pika::util::detail::bind(f_1, placeholders::_1))(x) == 11L);
     PIKA_TEST(
-        pika::util::detail::bind(f_2,
-            pika::util::detail::bind(f_1, placeholders::_1),
-            pika::util::detail::bind(f_1, placeholders::_2))(x, y) == 21L);
-    PIKA_TEST(pika::util::detail::bind(f_1, pika::util::detail::bind(f_0))() ==
-        17041L);
+        pika::util::detail::bind(f_1, pika::util::detail::bind(f_1, placeholders::_1))(x) == 1L);
+    PIKA_TEST(pika::util::detail::bind(f_1,
+                  pika::util::detail::bind(f_2, placeholders::_1, placeholders::_2))(x, y) == 21L);
+    PIKA_TEST(pika::util::detail::bind(f_2, pika::util::detail::bind(f_1, placeholders::_1),
+                  pika::util::detail::bind(f_1, placeholders::_1))(x) == 11L);
+    PIKA_TEST(pika::util::detail::bind(f_2, pika::util::detail::bind(f_1, placeholders::_1),
+                  pika::util::detail::bind(f_1, placeholders::_2))(x, y) == 21L);
+    PIKA_TEST(pika::util::detail::bind(f_1, pika::util::detail::bind(f_0))() == 17041L);
 
-    PIKA_TEST((pika::util::detail::bind(
-                   fv_1, pika::util::detail::bind(f_1, placeholders::_1))(x),
+    PIKA_TEST((pika::util::detail::bind(fv_1, pika::util::detail::bind(f_1, placeholders::_1))(x),
         (global_result == 1L)));
-    PIKA_TEST((pika::util::detail::bind(fv_1,
-                   pika::util::detail::bind(
-                       f_2, placeholders::_1, placeholders::_2))(x, y),
+    PIKA_TEST((pika::util::detail::bind(
+                   fv_1, pika::util::detail::bind(f_2, placeholders::_1, placeholders::_2))(x, y),
         (global_result == 21L)));
-    PIKA_TEST((pika::util::detail::bind(fv_2,
-                   pika::util::detail::bind(f_1, placeholders::_1),
+    PIKA_TEST((pika::util::detail::bind(fv_2, pika::util::detail::bind(f_1, placeholders::_1),
                    pika::util::detail::bind(f_1, placeholders::_1))(x),
         (global_result == 11L)));
-    PIKA_TEST((pika::util::detail::bind(fv_2,
-                   pika::util::detail::bind(f_1, placeholders::_1),
+    PIKA_TEST((pika::util::detail::bind(fv_2, pika::util::detail::bind(f_1, placeholders::_1),
                    pika::util::detail::bind(f_1, placeholders::_2))(x, y),
         (global_result == 21L)));
     PIKA_TEST((pika::util::detail::bind(fv_1, pika::util::detail::bind(f_0))(),
