@@ -23,8 +23,6 @@ void do_sum_avg(int values[], int n, int& sum, double& avg)
 
 int main()
 {
-    pika::util::detail::function<void(
-        int values[], int n, int& sum, double& avg)>
-        sum_avg;
+    pika::util::detail::function<void(int values[], int n, int& sum, double& avg)> sum_avg;
     sum_avg = &do_sum_avg;
 }
