@@ -82,16 +82,13 @@ namespace pika::lcos::local::detail {
                         this->set_value(f_());
                     }
                 },
-                [&](std::exception_ptr ep) {
-                    this->set_exception(PIKA_MOVE(ep));
-                });
+                [&](std::exception_ptr ep) { this->set_exception(PIKA_MOVE(ep)); });
         }
 
     protected:
         // run in a separate thread
-        threads::detail::thread_id_ref_type apply(
-            threads::detail::thread_pool_base* pool, const char* annotation,
-            launch policy, error_code& ec) override
+        threads::detail::thread_id_ref_type apply(threads::detail::thread_pool_base* pool,
+            const char* annotation, launch policy, error_code& ec) override
         {
             this->check_started();
 
@@ -100,27 +97,21 @@ namespace pika::lcos::local::detail {
             {
                 threads::detail::thread_init_data data(
                     threads::detail::make_thread_function_nullary(
-                        util::detail::deferred_call(
-                            &base_type::run_impl, PIKA_MOVE(this_))),
-                    ::pika::detail::thread_description(f_, annotation),
-                    policy.priority(),
+                        util::detail::deferred_call(&base_type::run_impl, PIKA_MOVE(this_))),
+                    ::pika::detail::thread_description(f_, annotation), policy.priority(),
                     execution::thread_schedule_hint(
                         static_cast<std::int16_t>(get_worker_thread_num())),
                     policy.stacksize(),
-                    threads::detail::thread_schedule_state::
-                        pending_do_not_schedule,
-                    true);
+                    threads::detail::thread_schedule_state::pending_do_not_schedule, true);
 
                 return threads::detail::register_thread(data, pool, ec);
             }
 
             threads::detail::thread_init_data data(
                 threads::detail::make_thread_function_nullary(
-                    util::detail::deferred_call(
-                        &base_type::run_impl, PIKA_MOVE(this_))),
-                ::pika::detail::thread_description(f_, annotation),
-                policy.priority(), policy.hint(), policy.stacksize(),
-                threads::detail::thread_schedule_state::pending);
+                    util::detail::deferred_call(&base_type::run_impl, PIKA_MOVE(this_))),
+                ::pika::detail::thread_description(f_, annotation), policy.priority(),
+                policy.hint(), policy.stacksize(), threads::detail::thread_schedule_state::pending);
 
             return threads::detail::register_work(data, pool, ec);
         }
@@ -133,8 +124,8 @@ namespace pika::lcos::local::detail {
         using result_type = typename base_type::result_type;
         using init_no_addref = typename base_type::init_no_addref;
 
-        using other_allocator = typename std::allocator_traits<
-            Allocator>::template rebind_alloc<task_object_allocator>;
+        using other_allocator =
+            typename std::allocator_traits<Allocator>::template rebind_alloc<task_object_allocator>;
 
         task_object_allocator(other_allocator const& alloc, F const& f)
           : base_type(f)
@@ -148,15 +139,14 @@ namespace pika::lcos::local::detail {
         {
         }
 
-        task_object_allocator(
-            init_no_addref no_addref, other_allocator const& alloc, F const& f)
+        task_object_allocator(init_no_addref no_addref, other_allocator const& alloc, F const& f)
           : base_type(no_addref, f)
           , alloc_(alloc)
         {
         }
 
-        task_object_allocator(init_no_addref no_addref,
-            other_allocator const& alloc, F&& f) noexcept
+        task_object_allocator(
+            init_no_addref no_addref, other_allocator const& alloc, F&& f) noexcept
           : base_type(no_addref, PIKA_MOVE(f))
           , alloc_(alloc)
         {
@@ -230,9 +220,8 @@ namespace pika::lcos::local::detail {
 
     protected:
         // run in a separate thread
-        threads::detail::thread_id_ref_type apply(
-            threads::detail::thread_pool_base* pool, const char* annotation,
-            launch policy, error_code& ec) override
+        threads::detail::thread_id_ref_type apply(threads::detail::thread_pool_base* pool,
+            const char* annotation, launch policy, error_code& ec) override
         {
             if (exec_)
             {
@@ -240,8 +229,7 @@ namespace pika::lcos::local::detail {
 
                 pika::intrusive_ptr<base_type> this_(this);
                 parallel::execution::post(*exec_,
-                    util::detail::deferred_call(
-                        &base_type::run_impl, PIKA_MOVE(this_)),
+                    util::detail::deferred_call(&base_type::run_impl, PIKA_MOVE(this_)),
                     exec_->get_schedulehint(), annotation);
                 return threads::detail::invalid_thread_id;
             }
@@ -258,8 +246,7 @@ namespace pika::lcos::local::detail {
     struct cancelable_task_object<Result, F, void>
       : task_object<Result, F, void, lcos::detail::cancelable_task_base<Result>>
     {
-        using base_type = task_object<Result, F, void,
-            lcos::detail::cancelable_task_base<Result>>;
+        using base_type = task_object<Result, F, void, lcos::detail::cancelable_task_base<Result>>;
         using result_type = typename base_type::result_type;
         using init_no_addref = typename base_type::init_no_addref;
 
@@ -285,25 +272,22 @@ namespace pika::lcos::local::detail {
     };
 
     template <typename Allocator, typename Result, typename F>
-    struct cancelable_task_object_allocator
-      : cancelable_task_object<Result, F, void>
+    struct cancelable_task_object_allocator : cancelable_task_object<Result, F, void>
     {
         using base_type = cancelable_task_object<Result, F, void>;
         using result_type = typename base_type::result_type;
         using init_no_addref = typename base_type::init_no_addref;
 
-        using other_allocator = typename std::allocator_traits<
-            Allocator>::template rebind_alloc<cancelable_task_object_allocator>;
+        using other_allocator = typename std::allocator_traits<Allocator>::template rebind_alloc<
+            cancelable_task_object_allocator>;
 
-        cancelable_task_object_allocator(
-            other_allocator const& alloc, F const& f)
+        cancelable_task_object_allocator(other_allocator const& alloc, F const& f)
           : base_type(f)
           , alloc_(alloc)
         {
         }
 
-        cancelable_task_object_allocator(
-            other_allocator const& alloc, F&& f) noexcept
+        cancelable_task_object_allocator(other_allocator const& alloc, F&& f) noexcept
           : base_type(PIKA_MOVE(f))
           , alloc_(alloc)
         {
@@ -316,8 +300,8 @@ namespace pika::lcos::local::detail {
         {
         }
 
-        cancelable_task_object_allocator(init_no_addref no_addref,
-            other_allocator const& alloc, F&& f) noexcept
+        cancelable_task_object_allocator(
+            init_no_addref no_addref, other_allocator const& alloc, F&& f) noexcept
           : base_type(no_addref, PIKA_MOVE(f))
           , alloc_(alloc)
         {
@@ -338,11 +322,10 @@ namespace pika::lcos::local::detail {
 
     template <typename Result, typename F, typename Executor>
     struct cancelable_task_object
-      : task_object<Result, F, Executor,
-            lcos::detail::cancelable_task_base<Result>>
+      : task_object<Result, F, Executor, lcos::detail::cancelable_task_base<Result>>
     {
-        using base_type = task_object<Result, F, Executor,
-            lcos::detail::cancelable_task_base<Result>>;
+        using base_type =
+            task_object<Result, F, Executor, lcos::detail::cancelable_task_base<Result>>;
         using result_type = typename base_type::result_type;
         using init_no_addref = typename base_type::init_no_addref;
 
@@ -376,14 +359,12 @@ namespace pika::lcos::local::detail {
         {
         }
 
-        cancelable_task_object(
-            Executor& exec, init_no_addref no_addref, F const& f)
+        cancelable_task_object(Executor& exec, init_no_addref no_addref, F const& f)
           : base_type(exec, no_addref, f)
         {
         }
 
-        cancelable_task_object(
-            Executor& exec, init_no_addref no_addref, F&& f) noexcept
+        cancelable_task_object(Executor& exec, init_no_addref no_addref, F&& f) noexcept
           : base_type(exec, no_addref, PIKA_MOVE(f))
         {
         }
@@ -393,20 +374,17 @@ namespace pika::lcos::local::detail {
 namespace pika::traits::detail {
 
     template <typename Result, typename F, typename Base, typename Allocator>
-    struct shared_state_allocator<
-        lcos::local::detail::task_object<Result, F, void, Base>, Allocator>
+    struct shared_state_allocator<lcos::local::detail::task_object<Result, F, void, Base>,
+        Allocator>
     {
-        using type = lcos::local::detail::task_object_allocator<Allocator,
-            Result, F, Base>;
+        using type = lcos::local::detail::task_object_allocator<Allocator, Result, F, Base>;
     };
 
     template <typename Result, typename F, typename Allocator>
-    struct shared_state_allocator<
-        lcos::local::detail::cancelable_task_object<Result, F, void>, Allocator>
+    struct shared_state_allocator<lcos::local::detail::cancelable_task_object<Result, F, void>,
+        Allocator>
     {
-        using type =
-            lcos::local::detail::cancelable_task_object_allocator<Allocator,
-                Result, F>;
+        using type = lcos::local::detail::cancelable_task_object_allocator<Allocator, Result, F>;
     };
 }    // namespace pika::traits::detail
 
@@ -429,25 +407,21 @@ namespace pika::lcos::local {
         template <typename Result>
         struct create_task_object<Result, false, void>
         {
-            using return_type =
-                pika::intrusive_ptr<lcos::detail::task_base<Result>>;
-            using init_no_addref =
-                typename lcos::detail::future_data_refcnt_base::init_no_addref;
+            using return_type = pika::intrusive_ptr<lcos::detail::task_base<Result>>;
+            using init_no_addref = typename lcos::detail::future_data_refcnt_base::init_no_addref;
 
             template <typename F>
             static return_type call(F&& f)
             {
-                return return_type(new task_object<Result, F, void>(
-                                       init_no_addref{}, PIKA_FORWARD(F, f)),
-                    false);
+                return return_type(
+                    new task_object<Result, F, void>(init_no_addref{}, PIKA_FORWARD(F, f)), false);
             }
 
             template <typename R>
             static return_type call(R (*f)())
             {
-                return return_type(new task_object<Result, Result (*)(), void>(
-                                       init_no_addref{}, f),
-                    false);
+                return return_type(
+                    new task_object<Result, Result (*)(), void>(init_no_addref{}, f), false);
             }
 
             template <typename Allocator, typename F>
@@ -455,34 +429,7 @@ namespace pika::lcos::local {
             {
                 using base_allocator = Allocator;
                 using shared_state =
-                    typename traits::detail::shared_state_allocator<
-                        task_object<Result, F, void>, base_allocator>::type;
-
-                using other_allocator = typename std::allocator_traits<
-                    base_allocator>::template rebind_alloc<shared_state>;
-                using traits = std::allocator_traits<other_allocator>;
-
-                using init_no_addref = typename shared_state::init_no_addref;
-
-                using unique_ptr = std::unique_ptr<shared_state,
-                    pika::detail::allocator_deleter<other_allocator>>;
-
-                other_allocator alloc(a);
-                unique_ptr p(traits::allocate(alloc, 1),
-                    pika::detail::allocator_deleter<other_allocator>{alloc});
-                traits::construct(alloc, p.get(), init_no_addref{}, alloc,
-                    PIKA_FORWARD(F, f));
-
-                return return_type(p.release(), false);
-            }
-
-            template <typename Allocator, typename R>
-            static return_type call(Allocator const& a, R (*f)())
-            {
-                using base_allocator = Allocator;
-                using shared_state =
-                    typename traits::detail::shared_state_allocator<
-                        task_object<Result, Result (*)(), void>,
+                    typename traits::detail::shared_state_allocator<task_object<Result, F, void>,
                         base_allocator>::type;
 
                 using other_allocator = typename std::allocator_traits<
@@ -491,8 +438,32 @@ namespace pika::lcos::local {
 
                 using init_no_addref = typename shared_state::init_no_addref;
 
-                using unique_ptr = std::unique_ptr<shared_state,
-                    pika::detail::allocator_deleter<other_allocator>>;
+                using unique_ptr =
+                    std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
+
+                other_allocator alloc(a);
+                unique_ptr p(traits::allocate(alloc, 1),
+                    pika::detail::allocator_deleter<other_allocator>{alloc});
+                traits::construct(alloc, p.get(), init_no_addref{}, alloc, PIKA_FORWARD(F, f));
+
+                return return_type(p.release(), false);
+            }
+
+            template <typename Allocator, typename R>
+            static return_type call(Allocator const& a, R (*f)())
+            {
+                using base_allocator = Allocator;
+                using shared_state = typename traits::detail::shared_state_allocator<
+                    task_object<Result, Result (*)(), void>, base_allocator>::type;
+
+                using other_allocator = typename std::allocator_traits<
+                    base_allocator>::template rebind_alloc<shared_state>;
+                using traits = std::allocator_traits<other_allocator>;
+
+                using init_no_addref = typename shared_state::init_no_addref;
+
+                using unique_ptr =
+                    std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
 
                 other_allocator alloc(a);
                 unique_ptr p(traits::allocate(alloc, 1),
@@ -504,19 +475,16 @@ namespace pika::lcos::local {
         };
 
         template <typename Result, typename Executor>
-        struct create_task_object<Result, false, Executor>
-          : create_task_object<Result, false, void>
+        struct create_task_object<Result, false, Executor> : create_task_object<Result, false, void>
         {
-            using return_type =
-                pika::intrusive_ptr<lcos::detail::task_base<Result>>;
-            using init_no_addref =
-                typename lcos::detail::future_data_refcnt_base::init_no_addref;
+            using return_type = pika::intrusive_ptr<lcos::detail::task_base<Result>>;
+            using init_no_addref = typename lcos::detail::future_data_refcnt_base::init_no_addref;
 
             template <typename F>
             static return_type call(Executor& exec, F&& f)
             {
-                return return_type(new task_object<Result, F, Executor>(exec,
-                                       init_no_addref{}, PIKA_FORWARD(F, f)),
+                return return_type(new task_object<Result, F, Executor>(
+                                       exec, init_no_addref{}, PIKA_FORWARD(F, f)),
                     false);
             }
 
@@ -524,8 +492,7 @@ namespace pika::lcos::local {
             static return_type call(Executor& exec, R (*f)())
             {
                 return return_type(
-                    new task_object<Result, Result (*)(), Executor>(
-                        exec, init_no_addref{}, f),
+                    new task_object<Result, Result (*)(), Executor>(exec, init_no_addref{}, f),
                     false);
             }
         };
@@ -534,10 +501,8 @@ namespace pika::lcos::local {
         template <typename Result>
         struct create_task_object<Result, true, void>
         {
-            using return_type =
-                pika::intrusive_ptr<lcos::detail::task_base<Result>>;
-            using init_no_addref =
-                typename lcos::detail::future_data_refcnt_base::init_no_addref;
+            using return_type = pika::intrusive_ptr<lcos::detail::task_base<Result>>;
+            using init_no_addref = typename lcos::detail::future_data_refcnt_base::init_no_addref;
 
             template <typename F>
             static return_type call(F&& f)
@@ -551,8 +516,7 @@ namespace pika::lcos::local {
             static return_type call(R (*f)())
             {
                 return return_type(
-                    new cancelable_task_object<Result, Result (*)(), void>(
-                        init_no_addref{}, f),
+                    new cancelable_task_object<Result, Result (*)(), void>(init_no_addref{}, f),
                     false);
             }
 
@@ -560,10 +524,8 @@ namespace pika::lcos::local {
             static return_type call(Allocator const& a, F&& f)
             {
                 using base_allocator = Allocator;
-                using shared_state =
-                    typename traits::detail::shared_state_allocator<
-                        cancelable_task_object<Result, F, void>,
-                        base_allocator>::type;
+                using shared_state = typename traits::detail::shared_state_allocator<
+                    cancelable_task_object<Result, F, void>, base_allocator>::type;
 
                 using other_allocator = typename std::allocator_traits<
                     base_allocator>::template rebind_alloc<shared_state>;
@@ -571,14 +533,13 @@ namespace pika::lcos::local {
 
                 using init_no_addref = typename shared_state::init_no_addref;
 
-                using unique_ptr = std::unique_ptr<shared_state,
-                    pika::detail::allocator_deleter<other_allocator>>;
+                using unique_ptr =
+                    std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
 
                 other_allocator alloc(a);
                 unique_ptr p(traits::allocate(alloc, 1),
                     pika::detail::allocator_deleter<other_allocator>{alloc});
-                traits::construct(alloc, p.get(), init_no_addref{}, alloc,
-                    PIKA_FORWARD(F, f));
+                traits::construct(alloc, p.get(), init_no_addref{}, alloc, PIKA_FORWARD(F, f));
 
                 return return_type(p.release(), false);
             }
@@ -587,10 +548,8 @@ namespace pika::lcos::local {
             static return_type call(Allocator const& a, R (*f)())
             {
                 using base_allocator = Allocator;
-                using shared_state =
-                    typename traits::detail::shared_state_allocator<
-                        cancelable_task_object<Result, Result (*)(), void>,
-                        base_allocator>::type;
+                using shared_state = typename traits::detail::shared_state_allocator<
+                    cancelable_task_object<Result, Result (*)(), void>, base_allocator>::type;
 
                 using other_allocator = typename std::allocator_traits<
                     base_allocator>::template rebind_alloc<shared_state>;
@@ -598,8 +557,8 @@ namespace pika::lcos::local {
 
                 using init_no_addref = typename shared_state::init_no_addref;
 
-                using unique_ptr = std::unique_ptr<shared_state,
-                    pika::detail::allocator_deleter<other_allocator>>;
+                using unique_ptr =
+                    std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
 
                 other_allocator alloc(a);
                 unique_ptr p(traits::allocate(alloc, 1),
@@ -611,29 +570,24 @@ namespace pika::lcos::local {
         };
 
         template <typename Result, typename Executor>
-        struct create_task_object<Result, true, Executor>
-          : create_task_object<Result, true, void>
+        struct create_task_object<Result, true, Executor> : create_task_object<Result, true, void>
         {
-            using return_type =
-                pika::intrusive_ptr<lcos::detail::task_base<Result>>;
-            using init_no_addref =
-                typename lcos::detail::future_data_refcnt_base::init_no_addref;
+            using return_type = pika::intrusive_ptr<lcos::detail::task_base<Result>>;
+            using init_no_addref = typename lcos::detail::future_data_refcnt_base::init_no_addref;
 
             template <typename F>
             static return_type call(Executor& exec, F&& f)
             {
-                return return_type(
-                    new cancelable_task_object<Result, F, Executor>(
-                        exec, init_no_addref{}, PIKA_FORWARD(F, f)),
+                return return_type(new cancelable_task_object<Result, F, Executor>(
+                                       exec, init_no_addref{}, PIKA_FORWARD(F, f)),
                     false);
             }
 
             template <typename R>
             static return_type call(Executor& exec, R (*f)())
             {
-                return return_type(
-                    new cancelable_task_object<Result, Result (*)(), Executor>(
-                        exec, init_no_addref{}, f),
+                return return_type(new cancelable_task_object<Result, Result (*)(), Executor>(
+                                       exec, init_no_addref{}, f),
                     false);
             }
         };
@@ -651,23 +605,19 @@ namespace pika::lcos::local {
 
         template <typename Executor, typename F>
         explicit futures_factory(Executor& exec, F&& f)
-          : task_(
-                detail::create_task_object<Result, Cancelable, Executor>::call(
-                    exec, PIKA_FORWARD(F, f)))
+          : task_(detail::create_task_object<Result, Cancelable, Executor>::call(
+                exec, PIKA_FORWARD(F, f)))
         {
         }
 
         template <typename Executor>
         explicit futures_factory(Executor& exec, Result (*f)())
-          : task_(
-                detail::create_task_object<Result, Cancelable, Executor>::call(
-                    exec, f))
+          : task_(detail::create_task_object<Result, Cancelable, Executor>::call(exec, f))
         {
         }
 
         template <typename F,
-            typename Enable = std::enable_if_t<
-                !std::is_same_v<std::decay_t<F>, futures_factory>>>
+            typename Enable = std::enable_if_t<!std::is_same_v<std::decay_t<F>, futures_factory>>>
         explicit futures_factory(F&& f)
           : task_(detail::create_task_object<Result, Cancelable>::call(
                 pika::detail::internal_allocator<>{}, PIKA_FORWARD(F, f)))
@@ -720,23 +670,19 @@ namespace pika::lcos::local {
         }
 
         // asynchronous execution
-        threads::detail::thread_id_ref_type apply(
-            const char* annotation = "futures_factory::apply",
+        threads::detail::thread_id_ref_type apply(const char* annotation = "futures_factory::apply",
             launch policy = launch::async, error_code& ec = throws) const
         {
-            return apply(threads::detail::get_self_or_default_pool(),
-                annotation, policy, ec);
+            return apply(threads::detail::get_self_or_default_pool(), annotation, policy, ec);
         }
 
-        threads::detail::thread_id_ref_type apply(
-            threads::detail::thread_pool_base* pool,
-            const char* annotation = "futures_factory::apply",
-            launch policy = launch::async, error_code& ec = throws) const
+        threads::detail::thread_id_ref_type apply(threads::detail::thread_pool_base* pool,
+            const char* annotation = "futures_factory::apply", launch policy = launch::async,
+            error_code& ec = throws) const
         {
             if (!task_)
             {
-                PIKA_THROW_EXCEPTION(pika::error::task_moved,
-                    "futures_factory<Result()>::apply()",
+                PIKA_THROW_EXCEPTION(pika::error::task_moved, "futures_factory<Result()>::apply()",
                     "futures_factory invalid (has it been moved?)");
                 return threads::detail::invalid_thread_id;
             }
@@ -749,8 +695,7 @@ namespace pika::lcos::local {
         {
             if (!task_)
             {
-                PIKA_THROWS_IF(ec, pika::error::task_moved,
-                    "futures_factory<Result()>::get_future",
+                PIKA_THROWS_IF(ec, pika::error::task_moved, "futures_factory<Result()>::get_future",
                     "futures_factory invalid (has it been moved?)");
                 return pika::future<Result>();
             }
@@ -765,8 +710,7 @@ namespace pika::lcos::local {
             future_obtained_ = true;
 
             using traits::future_access;
-            return future_access<pika::future<Result>>::create(
-                PIKA_MOVE(task_));
+            return future_access<pika::future<Result>>::create(PIKA_MOVE(task_));
         }
 
         constexpr bool valid() const noexcept
