@@ -52,8 +52,7 @@ struct additional_argument_executor
     template <typename F, typename... Ts>
     decltype(auto) async_execute(F&& f, Ts&&... ts)
     {
-        return pika::async(
-            std::forward<F>(f), additional_argument{}, std::forward<Ts>(ts)...);
+        return pika::async(std::forward<F>(f), additional_argument{}, std::forward<Ts>(ts)...);
     }
 
     template <typename A, typename... Ts>
@@ -131,8 +130,8 @@ void function_pointers(Executor& exec)
     int_f2_count.store(0);
 
     future<void> f1 = dataflow(exec, unwrapping(&void_f1), async(&int_f));
-    future<int> f2 = dataflow(exec, unwrapping(&int_f1),
-        dataflow(exec, unwrapping(&int_f1), make_ready_future(42)));
+    future<int> f2 = dataflow(
+        exec, unwrapping(&int_f1), dataflow(exec, unwrapping(&int_f1), make_ready_future(42)));
     future<int> f3 = dataflow(exec, unwrapping(&int_f2),
         dataflow(exec, unwrapping(&int_f1), make_ready_future(42)),
         dataflow(exec, unwrapping(&int_f1), make_ready_future(37)));
@@ -141,8 +140,7 @@ void function_pointers(Executor& exec)
     std::vector<future<int>> vf;
     for (std::size_t i = 0; i < 10; ++i)
     {
-        vf.push_back(
-            dataflow(exec, unwrapping(&int_f1), make_ready_future(42)));
+        vf.push_back(dataflow(exec, unwrapping(&int_f1), make_ready_future(42)));
     }
     future<int> f4 = dataflow(exec, unwrapping(&int_f_vector), std::move(vf));
 
@@ -226,8 +224,8 @@ void future_function_pointers(Executor& exec)
     future_int_f1_count.store(0);
     future_int_f2_count.store(0);
 
-    future<void> f1 = dataflow(exec, &future_void_f1,
-        async(&future_void_sf1, shared_future<void>(make_ready_future())));
+    future<void> f1 = dataflow(
+        exec, &future_void_f1, async(&future_void_sf1, shared_future<void>(make_ready_future())));
 
     f1.wait();
 
@@ -253,9 +251,9 @@ void future_function_pointers(Executor& exec)
     PIKA_TEST_EQ(future_int_f1_count, 1u);
     future_int_f1_count.store(0);
 
-    future<int> f4 = dataflow(exec, &future_int_f2,
-        dataflow(exec, &future_int_f1, make_ready_future()),
-        dataflow(exec, &future_int_f1, make_ready_future()));
+    future<int> f4 =
+        dataflow(exec, &future_int_f2, dataflow(exec, &future_int_f1, make_ready_future()),
+            dataflow(exec, &future_int_f1, make_ready_future()));
 
     PIKA_TEST_EQ(f4.get(), 2);
     PIKA_TEST_EQ(future_int_f1_count, 2u);
@@ -342,10 +340,8 @@ void plain_deferred_arguments(Executor& exec)
     int_f5_count.store(0);
 
     {
-        future<void> f1 =
-            dataflow(exec, &void_f5, 42, async(pika::launch::deferred, &int_f));
-        future<int> f2 =
-            dataflow(exec, &int_f5, 42, async(pika::launch::deferred, &int_f));
+        future<void> f1 = dataflow(exec, &void_f5, 42, async(pika::launch::deferred, &int_f));
+        future<int> f2 = dataflow(exec, &int_f5, 42, async(pika::launch::deferred, &int_f));
 
         f1.wait();
         PIKA_TEST_EQ(void_f5_count, 1u);
@@ -399,7 +395,7 @@ int main(int argc, char* argv[])
     pika::init_params init_args;
     init_args.cfg = cfg;
 
-    PIKA_TEST_EQ_MSG(pika::init(pika_main, argc, argv, init_args), 0,
-        "pika main exited with non-zero status");
+    PIKA_TEST_EQ_MSG(
+        pika::init(pika_main, argc, argv, init_args), 0, "pika main exited with non-zero status");
     return 0;
 }
