@@ -11,7 +11,6 @@
 #include <pika/assert.hpp>
 #include <pika/functional/detail/invoke.hpp>
 #include <pika/functional/invoke_fused.hpp>
-#include <pika/functional/invoke_result.hpp>
 #include <pika/futures/traits/future_access.hpp>
 #include <pika/memory/intrusive_ptr.hpp>
 #include <pika/pack_traversal/detail/container_category.hpp>
@@ -66,8 +65,8 @@ namespace pika {
 
         /// Creates a sequence from begin to end explicitly
         template <std::size_t Begin, std::size_t End>
-        using explicit_range_sequence_of_t = typename relocate_index_pack<Begin,
-            typename make_index_pack<End - Begin>::type>::type;
+        using explicit_range_sequence_of_t =
+            typename relocate_index_pack<Begin, typename make_index_pack<End - Begin>::type>::type;
 
         /// Continues the traversal when the object is called
         template <typename Frame, typename State>
@@ -92,11 +91,9 @@ namespace pika {
         /// given iterator tuple.
         template <typename Frame, typename State>
         auto make_resume_traversal_callable(Frame&& frame, State&& state)
-            -> resume_traversal_callable<std::decay_t<Frame>,
-                std::decay_t<State>>
+            -> resume_traversal_callable<std::decay_t<Frame>, std::decay_t<State>>
         {
-            return resume_traversal_callable<std::decay_t<Frame>,
-                std::decay_t<State>>(
+            return resume_traversal_callable<std::decay_t<Frame>, std::decay_t<State>>(
                 PIKA_FORWARD(Frame, frame), PIKA_FORWARD(State, state));
         }
 
@@ -133,8 +130,8 @@ namespace pika {
             }
 
             template <typename MapperArg>
-            explicit async_traversal_frame(async_traverse_in_place_tag<Visitor>,
-                MapperArg&& mapper_arg, Args... args)
+            explicit async_traversal_frame(
+                async_traverse_in_place_tag<Visitor>, MapperArg&& mapper_arg, Args... args)
               : Visitor(PIKA_FORWARD(MapperArg, mapper_arg))
               , args_(std::make_tuple(PIKA_MOVE(args)...))
               , finished_(false)
@@ -149,12 +146,9 @@ namespace pika {
 
             /// Calls the visitor with the given element
             template <typename T>
-            auto traverse(T&& value) ->
-                typename pika::util::detail::invoke_result<Visitor&,
-                    async_traverse_visit_tag, T>::type
+            auto traverse(T&& value) -> std::invoke_result_t<Visitor&, async_traverse_visit_tag, T>
             {
-                return PIKA_INVOKE(visitor(), async_traverse_visit_tag{},
-                    PIKA_FORWARD(T, value));
+                return PIKA_INVOKE(visitor(), async_traverse_visit_tag{}, PIKA_FORWARD(T, value));
             }
 
             /// Calls the visitor with the given element and a continuation
@@ -173,8 +167,8 @@ namespace pika {
 
                 // Invoke the visitor with the current value and the
                 // callable object to resume the control flow.
-                PIKA_INVOKE(visitor(), async_traverse_detach_tag{},
-                    PIKA_FORWARD(T, value), PIKA_MOVE(resumable));
+                PIKA_INVOKE(visitor(), async_traverse_detach_tag{}, PIKA_FORWARD(T, value),
+                    PIKA_MOVE(resumable));
             }
 
             /// Calls the visitor with no arguments to signalize that the
@@ -183,28 +177,26 @@ namespace pika {
             {
                 bool expected = false;
 #if defined(PIKA_GCC_VERSION) && PIKA_GCC_VERSION >= 120000
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wstringop-overflow"
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wstringop-overflow"
 #endif
                 if (finished_.compare_exchange_strong(expected, true))
 #if defined(PIKA_GCC_VERSION) && PIKA_GCC_VERSION >= 120000
-#pragma GCC diagnostic pop
+# pragma GCC diagnostic pop
 #endif
                 {
-                    PIKA_INVOKE(visitor(), async_traverse_complete_tag{},
-                        PIKA_MOVE(args_));
+                    PIKA_INVOKE(visitor(), async_traverse_complete_tag{}, PIKA_MOVE(args_));
                 }
             }
         };
 
         /// Stores the visitor and the arguments to traverse
         template <typename Allocator, typename Visitor, typename... Args>
-        class async_traversal_frame_allocator
-          : public async_traversal_frame<Visitor, Args...>
+        class async_traversal_frame_allocator : public async_traversal_frame<Visitor, Args...>
         {
             using base_type = async_traversal_frame<Visitor, Args...>;
-            using other_allocator = typename std::allocator_traits<Allocator>::
-                template rebind_alloc<async_traversal_frame_allocator>;
+            using other_allocator = typename std::allocator_traits<
+                Allocator>::template rebind_alloc<async_traversal_frame_allocator>;
 
         public:
             explicit async_traversal_frame_allocator(
@@ -215,12 +207,9 @@ namespace pika {
             }
 
             template <typename MapperArg>
-            explicit async_traversal_frame_allocator(
-                other_allocator const& alloc,
-                async_traverse_in_place_tag<Visitor> tag,
-                MapperArg&& mapper_arg, Args... args)
-              : base_type(tag, PIKA_FORWARD(MapperArg, mapper_arg),
-                    PIKA_MOVE(args)...)
+            explicit async_traversal_frame_allocator(other_allocator const& alloc,
+                async_traverse_in_place_tag<Visitor> tag, MapperArg&& mapper_arg, Args... args)
+              : base_type(tag, PIKA_FORWARD(MapperArg, mapper_arg), PIKA_MOVE(args)...)
               , alloc_(alloc)
             {
             }
@@ -241,12 +230,10 @@ namespace pika {
 
     namespace traits::detail {
         template <typename Visitor, typename... Args, typename Allocator>
-        struct shared_state_allocator<
-            util::detail::async_traversal_frame<Visitor, Args...>, Allocator>
+        struct shared_state_allocator<util::detail::async_traversal_frame<Visitor, Args...>,
+            Allocator>
         {
-            using type =
-                util::detail::async_traversal_frame_allocator<Allocator,
-                    Visitor, Args...>;
+            using type = util::detail::async_traversal_frame_allocator<Allocator, Visitor, Args...>;
         };
     }    // namespace traits::detail
 
@@ -268,8 +255,7 @@ namespace pika {
                 rhs.target_ = nullptr;
             }
 
-            static_async_range& operator=(
-                static_async_range const& rhs) = default;
+            static_async_range& operator=(static_async_range const& rhs) = default;
             static_async_range& operator=(static_async_range&& rhs)
             {
                 if (&rhs != this)
@@ -280,21 +266,18 @@ namespace pika {
                 return *this;
             }
 
-            constexpr auto operator*() const noexcept
-                -> decltype(std::get<Begin>(*target_))
+            constexpr auto operator*() const noexcept -> decltype(std::get<Begin>(*target_))
             {
                 return std::get<Begin>(*target_);
             }
 
             template <std::size_t Position>
-            constexpr static_async_range<Target, Position, End>
-            relocate() const noexcept
+            constexpr static_async_range<Target, Position, End> relocate() const noexcept
             {
                 return static_async_range<Target, Position, End>{target_};
             }
 
-            constexpr static_async_range<Target, Begin + 1, End>
-            next() const noexcept
+            constexpr static_async_range<Target, Begin + 1, End> next() const noexcept
             {
                 return static_async_range<Target, Begin + 1, End>{target_};
             }
@@ -320,8 +303,8 @@ namespace pika {
 
         /// Returns a static range for the given type
         template <typename T,
-            typename Range = static_async_range<std::decay_t<T>, 0U,
-                std::tuple_size<std::decay_t<T>>::value>>
+            typename Range =
+                static_async_range<std::decay_t<T>, 0U, std::tuple_size<std::decay_t<T>>::value>>
         Range make_static_range(T&& element)
         {
             auto pointer = std::addressof(element);
@@ -340,8 +323,7 @@ namespace pika {
                 return *this;
             }
 
-            auto operator*() const noexcept
-                -> decltype(*std::declval<Begin const&>())
+            auto operator*() const noexcept -> decltype(*std::declval<Begin const&>())
             {
                 return *begin_;
             }
@@ -360,9 +342,9 @@ namespace pika {
         };
 
         template <typename T>
-        using dynamic_async_range_of_t = dynamic_async_range<
-            std::decay_t<decltype(std::begin(std::declval<T>()))>,
-            std::decay_t<decltype(std::end(std::declval<T>()))>>;
+        using dynamic_async_range_of_t =
+            dynamic_async_range<std::decay_t<decltype(std::begin(std::declval<T>()))>,
+                std::decay_t<decltype(std::end(std::declval<T>()))>>;
 
         /// Returns a dynamic range for the given type
         template <typename T, typename Range = dynamic_async_range_of_t<T>>
@@ -374,8 +356,7 @@ namespace pika {
         template <typename T, typename Range = dynamic_async_range_of_t<T>>
         Range make_dynamic_async_range(std::reference_wrapper<T> ref_element)
         {
-            return Range{
-                std::begin(ref_element.get()), std::end(ref_element.get())};
+            return Range{std::begin(ref_element.get()), std::end(ref_element.get())};
         }
 
         /// Represents a particular point in a asynchronous traversal hierarchy
@@ -410,16 +391,16 @@ namespace pika {
 
             /// Creates a new traversal point which
             template <typename Parent>
-            auto push(Parent&& parent) -> async_traversal_point<Frame,
-                std::decay_t<Parent>, Hierarchy...>
+            auto push(Parent&& parent)
+                -> async_traversal_point<Frame, std::decay_t<Parent>, Hierarchy...>
             {
                 // Create a new hierarchy which contains the
                 // the parent (the last traversed element).
-                auto hierarchy = std::tuple_cat(
-                    std::make_tuple(PIKA_FORWARD(Parent, parent)), hierarchy_);
+                auto hierarchy =
+                    std::tuple_cat(std::make_tuple(PIKA_FORWARD(Parent, parent)), hierarchy_);
 
-                return async_traversal_point<Frame, std::decay_t<Parent>,
-                    Hierarchy...>(frame_, PIKA_MOVE(hierarchy), detached_);
+                return async_traversal_point<Frame, std::decay_t<Parent>, Hierarchy...>(
+                    frame_, PIKA_MOVE(hierarchy), detached_);
             }
 
             /// Forks the current traversal point and continues the child
@@ -448,8 +429,7 @@ namespace pika {
             template <typename Current,
                 typename = std::void_t<decltype(std::declval<Frame>()->traverse(
                     *std::declval<Current>()))>>
-            void async_traverse_one_impl(
-                container_category_tag<false, false>, Current&& current)
+            void async_traverse_one_impl(container_category_tag<false, false>, Current&& current)
             /// SFINAE this out if the visitor doesn't accept
             /// the given element
             {
@@ -457,8 +437,7 @@ namespace pika {
                 {
                     // Store the current call hierarchy into a tuple for
                     // later re-entrance.
-                    auto hierarchy = std::tuple_cat(
-                        std::make_tuple(current.next()), hierarchy_);
+                    auto hierarchy = std::tuple_cat(std::make_tuple(current.next()), hierarchy_);
 
                     // First detach the current execution context
                     detach();
@@ -474,8 +453,8 @@ namespace pika {
             /// Async traverse a single element which is a container or
             /// tuple like type.
             template <bool IsTupleLike, typename Current>
-            void async_traverse_one_impl(
-                container_category_tag<true, IsTupleLike>, Current&& current)
+            void
+            async_traverse_one_impl(container_category_tag<true, IsTupleLike>, Current&& current)
             {
                 auto range = make_dynamic_async_range(*current);
                 fork(PIKA_MOVE(range), PIKA_FORWARD(Current, current));
@@ -483,8 +462,7 @@ namespace pika {
 
             /// Async traverse a single element which is a tuple like type only.
             template <typename Current>
-            void async_traverse_one_impl(
-                container_category_tag<false, true>, Current&& current)
+            void async_traverse_one_impl(container_category_tag<false, true>, Current&& current)
             {
                 auto range = make_static_range(*current);
                 fork(PIKA_MOVE(range), PIKA_FORWARD(Current, current));
@@ -494,11 +472,9 @@ namespace pika {
             template <typename Current>
             void async_traverse_one(Current&& current)
             {
-                using ElementType = typename pika::detail::decay_unwrap<
-                    decltype(*current)>::type;
+                using ElementType = typename pika::detail::decay_unwrap<decltype(*current)>::type;
                 return async_traverse_one_impl(
-                    container_category_of_t<ElementType>{},
-                    PIKA_FORWARD(Current, current));
+                    container_category_of_t<ElementType>{}, PIKA_FORWARD(Current, current));
             }
 
             /// Async traverse the current iterator but don't traverse
@@ -513,12 +489,11 @@ namespace pika {
             }
 
             template <std::size_t... Sequence, typename Current>
-            void async_traverse_static_async_range(
-                index_pack<Sequence...>, Current&& current)
+            void async_traverse_static_async_range(index_pack<Sequence...>, Current&& current)
             {
-                int dummy[] = {((void) async_traverse_one_checked(
-                                    current.template relocate<Sequence>()),
-                                   0)...,
+                int dummy[] = {
+                    ((void) async_traverse_one_checked(current.template relocate<Sequence>()),
+                        0)...,
                     0};
                 (void) dummy;
             }
@@ -550,8 +525,8 @@ namespace pika {
         /// Deduces to the traversal point class of the
         /// given frame and hierarchy
         template <typename Frame, typename... Hierarchy>
-        using traversal_point_of_t = async_traversal_point<std::decay_t<Frame>,
-            std::decay_t<Hierarchy>...>;
+        using traversal_point_of_t =
+            async_traversal_point<std::decay_t<Frame>, std::decay_t<Hierarchy>...>;
 
         /// A callable object which is capable of resuming an asynchronous
         /// pack traversal.
@@ -560,12 +535,10 @@ namespace pika {
             /// Reenter an asynchronous iterator pack and continue
             /// its traversal.
             template <typename Frame, typename Current, typename... Hierarchy>
-            void operator()(Frame&& frame, Current&& current,
-                Hierarchy&&... hierarchy) const
+            void operator()(Frame&& frame, Current&& current, Hierarchy&&... hierarchy) const
             {
                 bool detached = false;
-                next(detached, PIKA_FORWARD(Frame, frame),
-                    PIKA_FORWARD(Current, current),
+                next(detached, PIKA_FORWARD(Frame, frame), PIKA_FORWARD(Current, current),
                     PIKA_FORWARD(Hierarchy, hierarchy)...);
             }
 
@@ -576,8 +549,7 @@ namespace pika {
                 // hasn't reached its end.
                 if (!current.is_finished())
                 {
-                    traversal_point_of_t<Frame> point(
-                        frame, std::make_tuple(), detached);
+                    traversal_point_of_t<Frame> point(frame, std::make_tuple(), detached);
 
                     point.async_traverse(PIKA_FORWARD(Current, current));
 
@@ -593,10 +565,9 @@ namespace pika {
 
             /// Reenter an asynchronous iterator pack and continue
             /// its traversal.
-            template <typename Frame, typename Current, typename Parent,
-                typename... Hierarchy>
-            void next(bool& detached, Frame&& frame, Current&& current,
-                Parent&& parent, Hierarchy&&... hierarchy) const
+            template <typename Frame, typename Current, typename Parent, typename... Hierarchy>
+            void next(bool& detached, Frame&& frame, Current&& current, Parent&& parent,
+                Hierarchy&&... hierarchy) const
             {
                 // Only process the element if the current iterator
                 // hasn't reached its end.
@@ -632,8 +603,7 @@ namespace pika {
         void resume_traversal_callable<Frame, State>::operator()()
         {
             auto hierarchy = std::tuple_cat(std::make_tuple(frame_), state_);
-            util::detail::invoke_fused(
-                resume_state_callable{}, PIKA_MOVE(hierarchy));
+            util::detail::invoke_fused(resume_state_callable{}, PIKA_MOVE(hierarchy));
         }
 
         /// Gives access to types related to the traversal frame
@@ -642,8 +612,7 @@ namespace pika {
         {
             /// Deduces to the async traversal frame type of the given
             /// traversal arguments and mapper
-            using frame_type = async_traversal_frame<std::decay_t<Visitor>,
-                std::decay_t<Args>...>;
+            using frame_type = async_traversal_frame<std::decay_t<Visitor>, std::decay_t<Args>...>;
 
             /// The type of the frame pointer
             using frame_pointer_type = pika::intrusive_ptr<frame_type>;
@@ -653,8 +622,8 @@ namespace pika {
         };
 
         template <typename Visitor, typename VisitorArg, typename... Args>
-        struct async_traversal_types<async_traverse_in_place_tag<Visitor>,
-            VisitorArg, Args...> : async_traversal_types<Visitor, Args...>
+        struct async_traversal_types<async_traverse_in_place_tag<Visitor>, VisitorArg, Args...>
+          : async_traversal_types<Visitor, Args...>
         {
         };
 
@@ -670,15 +639,14 @@ namespace pika {
             // Create an intrusive_ptr without increasing its reference count
             // (it's already 'one').
             auto frame = typename types::frame_pointer_type(new
-                typename types::frame_type(PIKA_FORWARD(Visitor, visitor),
-                    PIKA_FORWARD(Args, args)...),
+                typename types::frame_type(
+                    PIKA_FORWARD(Visitor, visitor), PIKA_FORWARD(Args, args)...),
                 false);
 
             // Create a static range for the top level tuple
             auto range = make_static_range(frame->head());
 
-            auto resumer = make_resume_traversal_callable(
-                frame, std::make_tuple(PIKA_MOVE(range)));
+            auto resumer = make_resume_traversal_callable(frame, std::make_tuple(PIKA_MOVE(range)));
 
             // Start the asynchronous traversal
             resumer();
@@ -689,9 +657,8 @@ namespace pika {
         /// to allocate the traversal frame
         template <typename Allocator, typename Visitor, typename... Args,
             typename types = async_traversal_types<Visitor, Args...>>
-        auto apply_pack_transform_async_allocator(
-            Allocator const& a, Visitor&& visitor, Args&&... args) ->
-            typename types::visitor_pointer_type
+        auto apply_pack_transform_async_allocator(Allocator const& a, Visitor&& visitor,
+            Args&&... args) -> typename types::visitor_pointer_type
         {
             // Create the frame on the heap which stores the arguments
             // to traverse asynchronously.
@@ -699,29 +666,28 @@ namespace pika {
             // Create an intrusive_ptr without increasing its reference count
             // (it's already 'one').
             using shared_state =
-                typename traits::detail::shared_state_allocator<
-                    typename types::frame_type, Allocator>::type;
+                typename traits::detail::shared_state_allocator<typename types::frame_type,
+                    Allocator>::type;
 
-            using other_allocator = typename std::allocator_traits<
-                Allocator>::template rebind_alloc<shared_state>;
+            using other_allocator =
+                typename std::allocator_traits<Allocator>::template rebind_alloc<shared_state>;
             using traits = std::allocator_traits<other_allocator>;
 
-            using unique_ptr = std::unique_ptr<shared_state,
-                pika::detail::allocator_deleter<other_allocator>>;
+            using unique_ptr =
+                std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
 
             other_allocator frame_alloc(a);
             unique_ptr p(traits::allocate(frame_alloc, 1),
                 pika::detail::allocator_deleter<other_allocator>{frame_alloc});
-            traits::construct(frame_alloc, p.get(), frame_alloc,
-                PIKA_FORWARD(Visitor, visitor), PIKA_FORWARD(Args, args)...);
+            traits::construct(frame_alloc, p.get(), frame_alloc, PIKA_FORWARD(Visitor, visitor),
+                PIKA_FORWARD(Args, args)...);
 
             auto frame = typename types::frame_pointer_type(p.release(), false);
 
             // Create a static range for the top level tuple
             auto range = make_static_range(frame->head());
 
-            auto resumer = make_resume_traversal_callable(
-                frame, std::make_tuple(PIKA_MOVE(range)));
+            auto resumer = make_resume_traversal_callable(frame, std::make_tuple(PIKA_MOVE(range)));
 
             // Start the asynchronous traversal
             resumer();
