@@ -15,19 +15,15 @@
 #include <string>
 #include <utility>
 
-namespace pika::string_util {
-    namespace detail {
-        template <typename It, typename CharT, typename Traits,
-            typename Allocator>
-        std::basic_string<CharT, Traits, Allocator>
-        substr(std::basic_string<CharT, Traits, Allocator> const& s,
-            It const& first, It const& last)
-        {
-            std::size_t const pos = std::distance(std::begin(s), first);
-            std::size_t const count = std::distance(first, last);
-            return s.substr(pos, count);
-        }
-    }    // namespace detail
+namespace pika::detail {
+    template <typename It, typename CharT, typename Traits, typename Allocator>
+    std::basic_string<CharT, Traits, Allocator>
+    substr(std::basic_string<CharT, Traits, Allocator> const& s, It const& first, It const& last)
+    {
+        std::size_t const pos = std::distance(std::begin(s), first);
+        std::size_t const count = std::distance(first, last);
+        return s.substr(pos, count);
+    }
 
     enum class token_compress_mode
     {
@@ -35,12 +31,10 @@ namespace pika::string_util {
         on
     };
 
-    template <typename Container, typename Predicate, typename CharT,
-        typename Traits, typename Allocator>
-    void split(Container& container,
-        std::basic_string<CharT, Traits, Allocator> const& str,
-        Predicate&& pred,
-        token_compress_mode compress_mode = token_compress_mode::off)
+    template <typename Container, typename Predicate, typename CharT, typename Traits,
+        typename Allocator>
+    void split(Container& container, std::basic_string<CharT, Traits, Allocator> const& str,
+        Predicate&& pred, token_compress_mode compress_mode = token_compress_mode::off)
     {
         container.clear();
 
@@ -51,7 +45,7 @@ namespace pika::string_util {
         {
             token_end = std::find_if(token_begin, std::end(str), pred);
 
-            container.push_back(detail::substr(str, token_begin, token_end));
+            container.push_back(substr(str, token_begin, token_end));
 
             if (token_end != std::end(str))
             {
@@ -73,7 +67,6 @@ namespace pika::string_util {
     void split(Container& container, char const* str, Predicate&& pred,
         token_compress_mode compress_mode = token_compress_mode::off)
     {
-        split(container, std::string{str}, PIKA_FORWARD(Predicate, pred),
-            compress_mode);
+        split(container, std::string{str}, PIKA_FORWARD(Predicate, pred), compress_mode);
     }
-}    // namespace pika::string_util
+}    // namespace pika::detail
