@@ -13,7 +13,6 @@
 #include <pika/functional/function.hpp>
 #include <pika/modules/errors.hpp>
 #include <pika/threading_base/callback_notifier.hpp>
-#include <pika/threading_base/network_background_callback.hpp>
 #include <pika/threading_base/scheduler_mode.hpp>
 #include <pika/threading_base/scheduler_state.hpp>
 #include <pika/threading_base/thread_init_data.hpp>
@@ -119,8 +118,6 @@ namespace pika::threads::detail {
         std::size_t thread_offset_;
         pika::threads::callback_notifier& notifier_;
         pika::detail::affinity_data const& affinity_data_;
-        pika::threads::detail::network_background_callback_type const& network_background_callback_;
-        std::size_t max_background_threads_;
         std::size_t max_idle_loop_count_;
         std::size_t max_busy_loop_count_;
         std::size_t shutdown_check_count_;
@@ -130,10 +127,6 @@ namespace pika::threads::detail {
             std::size_t num_threads, std::size_t thread_offset,
             pika::threads::callback_notifier& notifier,
             pika::detail::affinity_data const& affinity_data,
-            pika::threads::detail::network_background_callback_type const&
-                network_background_callback =
-                    pika::threads::detail::network_background_callback_type(),
-            std::size_t max_background_threads = std::size_t(-1),
             std::size_t max_idle_loop_count = PIKA_IDLE_LOOP_COUNT_MAX,
             std::size_t max_busy_loop_count = PIKA_BUSY_LOOP_COUNT_MAX,
             std::size_t shutdown_check_count = 10)
@@ -145,8 +138,6 @@ namespace pika::threads::detail {
           , thread_offset_(thread_offset)
           , notifier_(notifier)
           , affinity_data_(affinity_data)
-          , network_background_callback_(network_background_callback)
-          , max_background_threads_(max_background_threads)
           , max_idle_loop_count_(max_idle_loop_count)
           , max_busy_loop_count_(max_busy_loop_count)
           , shutdown_check_count_(shutdown_check_count)
@@ -385,11 +376,6 @@ namespace pika::threads::detail {
 
         virtual void get_idle_core_mask(mask_type&) const {}
 
-        virtual std::int64_t get_background_thread_count()
-        {
-            return 0;
-        }
-
         std::int64_t get_thread_count_unknown(std::size_t num_thread, bool reset)
         {
             return get_thread_count(thread_schedule_state::unknown,
